return <<'END';
00a0		<noBreak> 0020
00a8		<compat> 0020 0308
00aa		<super> 0061
00af		<compat> 0020 0304
00b2		<super> 0032
00b3		<super> 0033
00b4		<compat> 0020 0301
00b5		<compat> 03BC
00b8		<compat> 0020 0327
00b9		<super> 0031
00ba		<super> 006F
00bc		<fraction> 0031 2044 0034
00bd		<fraction> 0031 2044 0032
00be		<fraction> 0033 2044 0034
00c0		0041 0300
00c1		0041 0301
00c2		0041 0302
00c3		0041 0303
00c4		0041 0308
00c5		0041 030A
00c7		0043 0327
00c8		0045 0300
00c9		0045 0301
00ca		0045 0302
00cb		0045 0308
00cc		0049 0300
00cd		0049 0301
00ce		0049 0302
00cf		0049 0308
00d1		004E 0303
00d2		004F 0300
00d3		004F 0301
00d4		004F 0302
00d5		004F 0303
00d6		004F 0308
00d9		0055 0300
00da		0055 0301
00db		0055 0302
00dc		0055 0308
00dd		0059 0301
00e0		0061 0300
00e1		0061 0301
00e2		0061 0302
00e3		0061 0303
00e4		0061 0308
00e5		0061 030A
00e7		0063 0327
00e8		0065 0300
00e9		0065 0301
00ea		0065 0302
00eb		0065 0308
00ec		0069 0300
00ed		0069 0301
00ee		0069 0302
00ef		0069 0308
00f1		006E 0303
00f2		006F 0300
00f3		006F 0301
00f4		006F 0302
00f5		006F 0303
00f6		006F 0308
00f9		0075 0300
00fa		0075 0301
00fb		0075 0302
00fc		0075 0308
00fd		0079 0301
00ff		0079 0308
0100		0041 0304
0101		0061 0304
0102		0041 0306
0103		0061 0306
0104		0041 0328
0105		0061 0328
0106		0043 0301
0107		0063 0301
0108		0043 0302
0109		0063 0302
010a		0043 0307
010b		0063 0307
010c		0043 030C
010d		0063 030C
010e		0044 030C
010f		0064 030C
0112		0045 0304
0113		0065 0304
0114		0045 0306
0115		0065 0306
0116		0045 0307
0117		0065 0307
0118		0045 0328
0119		0065 0328
011a		0045 030C
011b		0065 030C
011c		0047 0302
011d		0067 0302
011e		0047 0306
011f		0067 0306
0120		0047 0307
0121		0067 0307
0122		0047 0327
0123		0067 0327
0124		0048 0302
0125		0068 0302
0128		0049 0303
0129		0069 0303
012a		0049 0304
012b		0069 0304
012c		0049 0306
012d		0069 0306
012e		0049 0328
012f		0069 0328
0130		0049 0307
0132		<compat> 0049 004A
0133		<compat> 0069 006A
0134		004A 0302
0135		006A 0302
0136		004B 0327
0137		006B 0327
0139		004C 0301
013a		006C 0301
013b		004C 0327
013c		006C 0327
013d		004C 030C
013e		006C 030C
013f		<compat> 004C 00B7
0140		<compat> 006C 00B7
0143		004E 0301
0144		006E 0301
0145		004E 0327
0146		006E 0327
0147		004E 030C
0148		006E 030C
0149		<compat> 02BC 006E
014c		004F 0304
014d		006F 0304
014e		004F 0306
014f		006F 0306
0150		004F 030B
0151		006F 030B
0154		0052 0301
0155		0072 0301
0156		0052 0327
0157		0072 0327
0158		0052 030C
0159		0072 030C
015a		0053 0301
015b		0073 0301
015c		0053 0302
015d		0073 0302
015e		0053 0327
015f		0073 0327
0160		0053 030C
0161		0073 030C
0162		0054 0327
0163		0074 0327
0164		0054 030C
0165		0074 030C
0168		0055 0303
0169		0075 0303
016a		0055 0304
016b		0075 0304
016c		0055 0306
016d		0075 0306
016e		0055 030A
016f		0075 030A
0170		0055 030B
0171		0075 030B
0172		0055 0328
0173		0075 0328
0174		0057 0302
0175		0077 0302
0176		0059 0302
0177		0079 0302
0178		0059 0308
0179		005A 0301
017a		007A 0301
017b		005A 0307
017c		007A 0307
017d		005A 030C
017e		007A 030C
017f		<compat> 0073
01a0		004F 031B
01a1		006F 031B
01af		0055 031B
01b0		0075 031B
01c4		<compat> 0044 017D
01c5		<compat> 0044 017E
01c6		<compat> 0064 017E
01c7		<compat> 004C 004A
01c8		<compat> 004C 006A
01c9		<compat> 006C 006A
01ca		<compat> 004E 004A
01cb		<compat> 004E 006A
01cc		<compat> 006E 006A
01cd		0041 030C
01ce		0061 030C
01cf		0049 030C
01d0		0069 030C
01d1		004F 030C
01d2		006F 030C
01d3		0055 030C
01d4		0075 030C
01d5		00DC 0304
01d6		00FC 0304
01d7		00DC 0301
01d8		00FC 0301
01d9		00DC 030C
01da		00FC 030C
01db		00DC 0300
01dc		00FC 0300
01de		00C4 0304
01df		00E4 0304
01e0		0226 0304
01e1		0227 0304
01e2		00C6 0304
01e3		00E6 0304
01e6		0047 030C
01e7		0067 030C
01e8		004B 030C
01e9		006B 030C
01ea		004F 0328
01eb		006F 0328
01ec		01EA 0304
01ed		01EB 0304
01ee		01B7 030C
01ef		0292 030C
01f0		006A 030C
01f1		<compat> 0044 005A
01f2		<compat> 0044 007A
01f3		<compat> 0064 007A
01f4		0047 0301
01f5		0067 0301
01f8		004E 0300
01f9		006E 0300
01fa		00C5 0301
01fb		00E5 0301
01fc		00C6 0301
01fd		00E6 0301
01fe		00D8 0301
01ff		00F8 0301
0200		0041 030F
0201		0061 030F
0202		0041 0311
0203		0061 0311
0204		0045 030F
0205		0065 030F
0206		0045 0311
0207		0065 0311
0208		0049 030F
0209		0069 030F
020a		0049 0311
020b		0069 0311
020c		004F 030F
020d		006F 030F
020e		004F 0311
020f		006F 0311
0210		0052 030F
0211		0072 030F
0212		0052 0311
0213		0072 0311
0214		0055 030F
0215		0075 030F
0216		0055 0311
0217		0075 0311
0218		0053 0326
0219		0073 0326
021a		0054 0326
021b		0074 0326
021e		0048 030C
021f		0068 030C
0226		0041 0307
0227		0061 0307
0228		0045 0327
0229		0065 0327
022a		00D6 0304
022b		00F6 0304
022c		00D5 0304
022d		00F5 0304
022e		004F 0307
022f		006F 0307
0230		022E 0304
0231		022F 0304
0232		0059 0304
0233		0079 0304
02b0		<super> 0068
02b1		<super> 0266
02b2		<super> 006A
02b3		<super> 0072
02b4		<super> 0279
02b5		<super> 027B
02b6		<super> 0281
02b7		<super> 0077
02b8		<super> 0079
02d8		<compat> 0020 0306
02d9		<compat> 0020 0307
02da		<compat> 0020 030A
02db		<compat> 0020 0328
02dc		<compat> 0020 0303
02dd		<compat> 0020 030B
02e0		<super> 0263
02e1		<super> 006C
02e2		<super> 0073
02e3		<super> 0078
02e4		<super> 0295
0340		0300
0341		0301
0343		0313
0344		0308 0301
0374		02B9
037a		<compat> 0020 0345
037e		003B
0384		<compat> 0020 0301
0385		00A8 0301
0386		0391 0301
0387		00B7
0388		0395 0301
0389		0397 0301
038a		0399 0301
038c		039F 0301
038e		03A5 0301
038f		03A9 0301
0390		03CA 0301
03aa		0399 0308
03ab		03A5 0308
03ac		03B1 0301
03ad		03B5 0301
03ae		03B7 0301
03af		03B9 0301
03b0		03CB 0301
03ca		03B9 0308
03cb		03C5 0308
03cc		03BF 0301
03cd		03C5 0301
03ce		03C9 0301
03d0		<compat> 03B2
03d1		<compat> 03B8
03d2		<compat> 03A5
03d3		03D2 0301
03d4		03D2 0308
03d5		<compat> 03C6
03d6		<compat> 03C0
03f0		<compat> 03BA
03f1		<compat> 03C1
03f2		<compat> 03C2
0400		0415 0300
0401		0415 0308
0403		0413 0301
0407		0406 0308
040c		041A 0301
040d		0418 0300
040e		0423 0306
0419		0418 0306
0439		0438 0306
0450		0435 0300
0451		0435 0308
0453		0433 0301
0457		0456 0308
045c		043A 0301
045d		0438 0300
045e		0443 0306
0476		0474 030F
0477		0475 030F
04c1		0416 0306
04c2		0436 0306
04d0		0410 0306
04d1		0430 0306
04d2		0410 0308
04d3		0430 0308
04d6		0415 0306
04d7		0435 0306
04da		04D8 0308
04db		04D9 0308
04dc		0416 0308
04dd		0436 0308
04de		0417 0308
04df		0437 0308
04e2		0418 0304
04e3		0438 0304
04e4		0418 0308
04e5		0438 0308
04e6		041E 0308
04e7		043E 0308
04ea		04E8 0308
04eb		04E9 0308
04ec		042D 0308
04ed		044D 0308
04ee		0423 0304
04ef		0443 0304
04f0		0423 0308
04f1		0443 0308
04f2		0423 030B
04f3		0443 030B
04f4		0427 0308
04f5		0447 0308
04f8		042B 0308
04f9		044B 0308
0587		<compat> 0565 0582
0622		0627 0653
0623		0627 0654
0624		0648 0654
0625		0627 0655
0626		064A 0654
0675		<compat> 0627 0674
0676		<compat> 0648 0674
0677		<compat> 06C7 0674
0678		<compat> 064A 0674
06c0		06D5 0654
06c2		06C1 0654
06d3		06D2 0654
0929		0928 093C
0931		0930 093C
0934		0933 093C
0958		0915 093C
0959		0916 093C
095a		0917 093C
095b		091C 093C
095c		0921 093C
095d		0922 093C
095e		092B 093C
095f		092F 093C
09cb		09C7 09BE
09cc		09C7 09D7
09dc		09A1 09BC
09dd		09A2 09BC
09df		09AF 09BC
0a33		0A32 0A3C
0a36		0A38 0A3C
0a59		0A16 0A3C
0a5a		0A17 0A3C
0a5b		0A1C 0A3C
0a5e		0A2B 0A3C
0b48		0B47 0B56
0b4b		0B47 0B3E
0b4c		0B47 0B57
0b5c		0B21 0B3C
0b5d		0B22 0B3C
0b94		0B92 0BD7
0bca		0BC6 0BBE
0bcb		0BC7 0BBE
0bcc		0BC6 0BD7
0c48		0C46 0C56
0cc0		0CBF 0CD5
0cc7		0CC6 0CD5
0cc8		0CC6 0CD6
0cca		0CC6 0CC2
0ccb		0CCA 0CD5
0d4a		0D46 0D3E
0d4b		0D47 0D3E
0d4c		0D46 0D57
0dda		0DD9 0DCA
0ddc		0DD9 0DCF
0ddd		0DDC 0DCA
0dde		0DD9 0DDF
0e33		<compat> 0E4D 0E32
0eb3		<compat> 0ECD 0EB2
0edc		<compat> 0EAB 0E99
0edd		<compat> 0EAB 0EA1
0f0c		<noBreak> 0F0B
0f43		0F42 0FB7
0f4d		0F4C 0FB7
0f52		0F51 0FB7
0f57		0F56 0FB7
0f5c		0F5B 0FB7
0f69		0F40 0FB5
0f73		0F71 0F72
0f75		0F71 0F74
0f76		0FB2 0F80
0f77		<compat> 0FB2 0F81
0f78		0FB3 0F80
0f79		<compat> 0FB3 0F81
0f81		0F71 0F80
0f93		0F92 0FB7
0f9d		0F9C 0FB7
0fa2		0FA1 0FB7
0fa7		0FA6 0FB7
0fac		0FAB 0FB7
0fb9		0F90 0FB5
1026		1025 102E
1e00		0041 0325
1e01		0061 0325
1e02		0042 0307
1e03		0062 0307
1e04		0042 0323
1e05		0062 0323
1e06		0042 0331
1e07		0062 0331
1e08		00C7 0301
1e09		00E7 0301
1e0a		0044 0307
1e0b		0064 0307
1e0c		0044 0323
1e0d		0064 0323
1e0e		0044 0331
1e0f		0064 0331
1e10		0044 0327
1e11		0064 0327
1e12		0044 032D
1e13		0064 032D
1e14		0112 0300
1e15		0113 0300
1e16		0112 0301
1e17		0113 0301
1e18		0045 032D
1e19		0065 032D
1e1a		0045 0330
1e1b		0065 0330
1e1c		0228 0306
1e1d		0229 0306
1e1e		0046 0307
1e1f		0066 0307
1e20		0047 0304
1e21		0067 0304
1e22		0048 0307
1e23		0068 0307
1e24		0048 0323
1e25		0068 0323
1e26		0048 0308
1e27		0068 0308
1e28		0048 0327
1e29		0068 0327
1e2a		0048 032E
1e2b		0068 032E
1e2c		0049 0330
1e2d		0069 0330
1e2e		00CF 0301
1e2f		00EF 0301
1e30		004B 0301
1e31		006B 0301
1e32		004B 0323
1e33		006B 0323
1e34		004B 0331
1e35		006B 0331
1e36		004C 0323
1e37		006C 0323
1e38		1E36 0304
1e39		1E37 0304
1e3a		004C 0331
1e3b		006C 0331
1e3c		004C 032D
1e3d		006C 032D
1e3e		004D 0301
1e3f		006D 0301
1e40		004D 0307
1e41		006D 0307
1e42		004D 0323
1e43		006D 0323
1e44		004E 0307
1e45		006E 0307
1e46		004E 0323
1e47		006E 0323
1e48		004E 0331
1e49		006E 0331
1e4a		004E 032D
1e4b		006E 032D
1e4c		00D5 0301
1e4d		00F5 0301
1e4e		00D5 0308
1e4f		00F5 0308
1e50		014C 0300
1e51		014D 0300
1e52		014C 0301
1e53		014D 0301
1e54		0050 0301
1e55		0070 0301
1e56		0050 0307
1e57		0070 0307
1e58		0052 0307
1e59		0072 0307
1e5a		0052 0323
1e5b		0072 0323
1e5c		1E5A 0304
1e5d		1E5B 0304
1e5e		0052 0331
1e5f		0072 0331
1e60		0053 0307
1e61		0073 0307
1e62		0053 0323
1e63		0073 0323
1e64		015A 0307
1e65		015B 0307
1e66		0160 0307
1e67		0161 0307
1e68		1E62 0307
1e69		1E63 0307
1e6a		0054 0307
1e6b		0074 0307
1e6c		0054 0323
1e6d		0074 0323
1e6e		0054 0331
1e6f		0074 0331
1e70		0054 032D
1e71		0074 032D
1e72		0055 0324
1e73		0075 0324
1e74		0055 0330
1e75		0075 0330
1e76		0055 032D
1e77		0075 032D
1e78		0168 0301
1e79		0169 0301
1e7a		016A 0308
1e7b		016B 0308
1e7c		0056 0303
1e7d		0076 0303
1e7e		0056 0323
1e7f		0076 0323
1e80		0057 0300
1e81		0077 0300
1e82		0057 0301
1e83		0077 0301
1e84		0057 0308
1e85		0077 0308
1e86		0057 0307
1e87		0077 0307
1e88		0057 0323
1e89		0077 0323
1e8a		0058 0307
1e8b		0078 0307
1e8c		0058 0308
1e8d		0078 0308
1e8e		0059 0307
1e8f		0079 0307
1e90		005A 0302
1e91		007A 0302
1e92		005A 0323
1e93		007A 0323
1e94		005A 0331
1e95		007A 0331
1e96		0068 0331
1e97		0074 0308
1e98		0077 030A
1e99		0079 030A
1e9a		<compat> 0061 02BE
1e9b		017F 0307
1ea0		0041 0323
1ea1		0061 0323
1ea2		0041 0309
1ea3		0061 0309
1ea4		00C2 0301
1ea5		00E2 0301
1ea6		00C2 0300
1ea7		00E2 0300
1ea8		00C2 0309
1ea9		00E2 0309
1eaa		00C2 0303
1eab		00E2 0303
1eac		1EA0 0302
1ead		1EA1 0302
1eae		0102 0301
1eaf		0103 0301
1eb0		0102 0300
1eb1		0103 0300
1eb2		0102 0309
1eb3		0103 0309
1eb4		0102 0303
1eb5		0103 0303
1eb6		1EA0 0306
1eb7		1EA1 0306
1eb8		0045 0323
1eb9		0065 0323
1eba		0045 0309
1ebb		0065 0309
1ebc		0045 0303
1ebd		0065 0303
1ebe		00CA 0301
1ebf		00EA 0301
1ec0		00CA 0300
1ec1		00EA 0300
1ec2		00CA 0309
1ec3		00EA 0309
1ec4		00CA 0303
1ec5		00EA 0303
1ec6		1EB8 0302
1ec7		1EB9 0302
1ec8		0049 0309
1ec9		0069 0309
1eca		0049 0323
1ecb		0069 0323
1ecc		004F 0323
1ecd		006F 0323
1ece		004F 0309
1ecf		006F 0309
1ed0		00D4 0301
1ed1		00F4 0301
1ed2		00D4 0300
1ed3		00F4 0300
1ed4		00D4 0309
1ed5		00F4 0309
1ed6		00D4 0303
1ed7		00F4 0303
1ed8		1ECC 0302
1ed9		1ECD 0302
1eda		01A0 0301
1edb		01A1 0301
1edc		01A0 0300
1edd		01A1 0300
1ede		01A0 0309
1edf		01A1 0309
1ee0		01A0 0303
1ee1		01A1 0303
1ee2		01A0 0323
1ee3		01A1 0323
1ee4		0055 0323
1ee5		0075 0323
1ee6		0055 0309
1ee7		0075 0309
1ee8		01AF 0301
1ee9		01B0 0301
1eea		01AF 0300
1eeb		01B0 0300
1eec		01AF 0309
1eed		01B0 0309
1eee		01AF 0303
1eef		01B0 0303
1ef0		01AF 0323
1ef1		01B0 0323
1ef2		0059 0300
1ef3		0079 0300
1ef4		0059 0323
1ef5		0079 0323
1ef6		0059 0309
1ef7		0079 0309
1ef8		0059 0303
1ef9		0079 0303
1f00		03B1 0313
1f01		03B1 0314
1f02		1F00 0300
1f03		1F01 0300
1f04		1F00 0301
1f05		1F01 0301
1f06		1F00 0342
1f07		1F01 0342
1f08		0391 0313
1f09		0391 0314
1f0a		1F08 0300
1f0b		1F09 0300
1f0c		1F08 0301
1f0d		1F09 0301
1f0e		1F08 0342
1f0f		1F09 0342
1f10		03B5 0313
1f11		03B5 0314
1f12		1F10 0300
1f13		1F11 0300
1f14		1F10 0301
1f15		1F11 0301
1f18		0395 0313
1f19		0395 0314
1f1a		1F18 0300
1f1b		1F19 0300
1f1c		1F18 0301
1f1d		1F19 0301
1f20		03B7 0313
1f21		03B7 0314
1f22		1F20 0300
1f23		1F21 0300
1f24		1F20 0301
1f25		1F21 0301
1f26		1F20 0342
1f27		1F21 0342
1f28		0397 0313
1f29		0397 0314
1f2a		1F28 0300
1f2b		1F29 0300
1f2c		1F28 0301
1f2d		1F29 0301
1f2e		1F28 0342
1f2f		1F29 0342
1f30		03B9 0313
1f31		03B9 0314
1f32		1F30 0300
1f33		1F31 0300
1f34		1F30 0301
1f35		1F31 0301
1f36		1F30 0342
1f37		1F31 0342
1f38		0399 0313
1f39		0399 0314
1f3a		1F38 0300
1f3b		1F39 0300
1f3c		1F38 0301
1f3d		1F39 0301
1f3e		1F38 0342
1f3f		1F39 0342
1f40		03BF 0313
1f41		03BF 0314
1f42		1F40 0300
1f43		1F41 0300
1f44		1F40 0301
1f45		1F41 0301
1f48		039F 0313
1f49		039F 0314
1f4a		1F48 0300
1f4b		1F49 0300
1f4c		1F48 0301
1f4d		1F49 0301
1f50		03C5 0313
1f51		03C5 0314
1f52		1F50 0300
1f53		1F51 0300
1f54		1F50 0301
1f55		1F51 0301
1f56		1F50 0342
1f57		1F51 0342
1f59		03A5 0314
1f5b		1F59 0300
1f5d		1F59 0301
1f5f		1F59 0342
1f60		03C9 0313
1f61		03C9 0314
1f62		1F60 0300
1f63		1F61 0300
1f64		1F60 0301
1f65		1F61 0301
1f66		1F60 0342
1f67		1F61 0342
1f68		03A9 0313
1f69		03A9 0314
1f6a		1F68 0300
1f6b		1F69 0300
1f6c		1F68 0301
1f6d		1F69 0301
1f6e		1F68 0342
1f6f		1F69 0342
1f70		03B1 0300
1f71		03AC
1f72		03B5 0300
1f73		03AD
1f74		03B7 0300
1f75		03AE
1f76		03B9 0300
1f77		03AF
1f78		03BF 0300
1f79		03CC
1f7a		03C5 0300
1f7b		03CD
1f7c		03C9 0300
1f7d		03CE
1f80		1F00 0345
1f81		1F01 0345
1f82		1F02 0345
1f83		1F03 0345
1f84		1F04 0345
1f85		1F05 0345
1f86		1F06 0345
1f87		1F07 0345
1f88		1F08 0345
1f89		1F09 0345
1f8a		1F0A 0345
1f8b		1F0B 0345
1f8c		1F0C 0345
1f8d		1F0D 0345
1f8e		1F0E 0345
1f8f		1F0F 0345
1f90		1F20 0345
1f91		1F21 0345
1f92		1F22 0345
1f93		1F23 0345
1f94		1F24 0345
1f95		1F25 0345
1f96		1F26 0345
1f97		1F27 0345
1f98		1F28 0345
1f99		1F29 0345
1f9a		1F2A 0345
1f9b		1F2B 0345
1f9c		1F2C 0345
1f9d		1F2D 0345
1f9e		1F2E 0345
1f9f		1F2F 0345
1fa0		1F60 0345
1fa1		1F61 0345
1fa2		1F62 0345
1fa3		1F63 0345
1fa4		1F64 0345
1fa5		1F65 0345
1fa6		1F66 0345
1fa7		1F67 0345
1fa8		1F68 0345
1fa9		1F69 0345
1faa		1F6A 0345
1fab		1F6B 0345
1fac		1F6C 0345
1fad		1F6D 0345
1fae		1F6E 0345
1faf		1F6F 0345
1fb0		03B1 0306
1fb1		03B1 0304
1fb2		1F70 0345
1fb3		03B1 0345
1fb4		03AC 0345
1fb6		03B1 0342
1fb7		1FB6 0345
1fb8		0391 0306
1fb9		0391 0304
1fba		0391 0300
1fbb		0386
1fbc		0391 0345
1fbd		<compat> 0020 0313
1fbe		03B9
1fbf		<compat> 0020 0313
1fc0		<compat> 0020 0342
1fc1		00A8 0342
1fc2		1F74 0345
1fc3		03B7 0345
1fc4		03AE 0345
1fc6		03B7 0342
1fc7		1FC6 0345
1fc8		0395 0300
1fc9		0388
1fca		0397 0300
1fcb		0389
1fcc		0397 0345
1fcd		1FBF 0300
1fce		1FBF 0301
1fcf		1FBF 0342
1fd0		03B9 0306
1fd1		03B9 0304
1fd2		03CA 0300
1fd3		0390
1fd6		03B9 0342
1fd7		03CA 0342
1fd8		0399 0306
1fd9		0399 0304
1fda		0399 0300
1fdb		038A
1fdd		1FFE 0300
1fde		1FFE 0301
1fdf		1FFE 0342
1fe0		03C5 0306
1fe1		03C5 0304
1fe2		03CB 0300
1fe3		03B0
1fe4		03C1 0313
1fe5		03C1 0314
1fe6		03C5 0342
1fe7		03CB 0342
1fe8		03A5 0306
1fe9		03A5 0304
1fea		03A5 0300
1feb		038E
1fec		03A1 0314
1fed		00A8 0300
1fee		0385
1fef		0060
1ff2		1F7C 0345
1ff3		03C9 0345
1ff4		03CE 0345
1ff6		03C9 0342
1ff7		1FF6 0345
1ff8		039F 0300
1ff9		038C
1ffa		03A9 0300
1ffb		038F
1ffc		03A9 0345
1ffd		00B4
1ffe		<compat> 0020 0314
2000		2002
2001		2003
2002	2006	<compat> 0020
2007		<noBreak> 0020
2008	200a	<compat> 0020
2011		<noBreak> 2010
2017		<compat> 0020 0333
2024		<compat> 002E
2025		<compat> 002E 002E
2026		<compat> 002E 002E 002E
202f		<noBreak> 0020
2033		<compat> 2032 2032
2034		<compat> 2032 2032 2032
2036		<compat> 2035 2035
2037		<compat> 2035 2035 2035
203c		<compat> 0021 0021
203e		<compat> 0020 0305
2048		<compat> 003F 0021
2049		<compat> 0021 003F
2070		<super> 0030
2074		<super> 0034
2075		<super> 0035
2076		<super> 0036
2077		<super> 0037
2078		<super> 0038
2079		<super> 0039
207a		<super> 002B
207b		<super> 2212
207c		<super> 003D
207d		<super> 0028
207e		<super> 0029
207f		<super> 006E
2080		<sub> 0030
2081		<sub> 0031
2082		<sub> 0032
2083		<sub> 0033
2084		<sub> 0034
2085		<sub> 0035
2086		<sub> 0036
2087		<sub> 0037
2088		<sub> 0038
2089		<sub> 0039
208a		<sub> 002B
208b		<sub> 2212
208c		<sub> 003D
208d		<sub> 0028
208e		<sub> 0029
20a8		<compat> 0052 0073
2100		<compat> 0061 002F 0063
2101		<compat> 0061 002F 0073
2102		<font> 0043
2103		<compat> 00B0 0043
2105		<compat> 0063 002F 006F
2106		<compat> 0063 002F 0075
2107		<compat> 0190
2109		<compat> 00B0 0046
210a		<font> 0067
210b	210d	<font> 0048
210e		<font> 0068
210f		<font> 0127
2110	2111	<font> 0049
2112		<font> 004C
2113		<font> 006C
2115		<font> 004E
2116		<compat> 004E 006F
2119		<font> 0050
211a		<font> 0051
211b	211d	<font> 0052
2120		<super> 0053 004D
2121		<compat> 0054 0045 004C
2122		<super> 0054 004D
2124		<font> 005A
2126		03A9
2128		<font> 005A
212a		004B
212b		00C5
212c		<font> 0042
212d		<font> 0043
212f		<font> 0065
2130		<font> 0045
2131		<font> 0046
2133		<font> 004D
2134		<font> 006F
2135		<compat> 05D0
2136		<compat> 05D1
2137		<compat> 05D2
2138		<compat> 05D3
2139		<font> 0069
2153		<fraction> 0031 2044 0033
2154		<fraction> 0032 2044 0033
2155		<fraction> 0031 2044 0035
2156		<fraction> 0032 2044 0035
2157		<fraction> 0033 2044 0035
2158		<fraction> 0034 2044 0035
2159		<fraction> 0031 2044 0036
215a		<fraction> 0035 2044 0036
215b		<fraction> 0031 2044 0038
215c		<fraction> 0033 2044 0038
215d		<fraction> 0035 2044 0038
215e		<fraction> 0037 2044 0038
215f		<fraction> 0031 2044
2160		<compat> 0049
2161		<compat> 0049 0049
2162		<compat> 0049 0049 0049
2163		<compat> 0049 0056
2164		<compat> 0056
2165		<compat> 0056 0049
2166		<compat> 0056 0049 0049
2167		<compat> 0056 0049 0049 0049
2168		<compat> 0049 0058
2169		<compat> 0058
216a		<compat> 0058 0049
216b		<compat> 0058 0049 0049
216c		<compat> 004C
216d		<compat> 0043
216e		<compat> 0044
216f		<compat> 004D
2170		<compat> 0069
2171		<compat> 0069 0069
2172		<compat> 0069 0069 0069
2173		<compat> 0069 0076
2174		<compat> 0076
2175		<compat> 0076 0069
2176		<compat> 0076 0069 0069
2177		<compat> 0076 0069 0069 0069
2178		<compat> 0069 0078
2179		<compat> 0078
217a		<compat> 0078 0069
217b		<compat> 0078 0069 0069
217c		<compat> 006C
217d		<compat> 0063
217e		<compat> 0064
217f		<compat> 006D
219a		2190 0338
219b		2192 0338
21ae		2194 0338
21cd		21D0 0338
21ce		21D4 0338
21cf		21D2 0338
2204		2203 0338
2209		2208 0338
220c		220B 0338
2224		2223 0338
2226		2225 0338
222c		<compat> 222B 222B
222d		<compat> 222B 222B 222B
222f		<compat> 222E 222E
2230		<compat> 222E 222E 222E
2241		223C 0338
2244		2243 0338
2247		2245 0338
2249		2248 0338
2260		003D 0338
2262		2261 0338
226d		224D 0338
226e		003C 0338
226f		003E 0338
2270		2264 0338
2271		2265 0338
2274		2272 0338
2275		2273 0338
2278		2276 0338
2279		2277 0338
2280		227A 0338
2281		227B 0338
2284		2282 0338
2285		2283 0338
2288		2286 0338
2289		2287 0338
22ac		22A2 0338
22ad		22A8 0338
22ae		22A9 0338
22af		22AB 0338
22e0		227C 0338
22e1		227D 0338
22e2		2291 0338
22e3		2292 0338
22ea		22B2 0338
22eb		22B3 0338
22ec		22B4 0338
22ed		22B5 0338
2329		3008
232a		3009
2460		<circle> 0031
2461		<circle> 0032
2462		<circle> 0033
2463		<circle> 0034
2464		<circle> 0035
2465		<circle> 0036
2466		<circle> 0037
2467		<circle> 0038
2468		<circle> 0039
2469		<circle> 0031 0030
246a		<circle> 0031 0031
246b		<circle> 0031 0032
246c		<circle> 0031 0033
246d		<circle> 0031 0034
246e		<circle> 0031 0035
246f		<circle> 0031 0036
2470		<circle> 0031 0037
2471		<circle> 0031 0038
2472		<circle> 0031 0039
2473		<circle> 0032 0030
2474		<compat> 0028 0031 0029
2475		<compat> 0028 0032 0029
2476		<compat> 0028 0033 0029
2477		<compat> 0028 0034 0029
2478		<compat> 0028 0035 0029
2479		<compat> 0028 0036 0029
247a		<compat> 0028 0037 0029
247b		<compat> 0028 0038 0029
247c		<compat> 0028 0039 0029
247d		<compat> 0028 0031 0030 0029
247e		<compat> 0028 0031 0031 0029
247f		<compat> 0028 0031 0032 0029
2480		<compat> 0028 0031 0033 0029
2481		<compat> 0028 0031 0034 0029
2482		<compat> 0028 0031 0035 0029
2483		<compat> 0028 0031 0036 0029
2484		<compat> 0028 0031 0037 0029
2485		<compat> 0028 0031 0038 0029
2486		<compat> 0028 0031 0039 0029
2487		<compat> 0028 0032 0030 0029
2488		<compat> 0031 002E
2489		<compat> 0032 002E
248a		<compat> 0033 002E
248b		<compat> 0034 002E
248c		<compat> 0035 002E
248d		<compat> 0036 002E
248e		<compat> 0037 002E
248f		<compat> 0038 002E
2490		<compat> 0039 002E
2491		<compat> 0031 0030 002E
2492		<compat> 0031 0031 002E
2493		<compat> 0031 0032 002E
2494		<compat> 0031 0033 002E
2495		<compat> 0031 0034 002E
2496		<compat> 0031 0035 002E
2497		<compat> 0031 0036 002E
2498		<compat> 0031 0037 002E
2499		<compat> 0031 0038 002E
249a		<compat> 0031 0039 002E
249b		<compat> 0032 0030 002E
249c		<compat> 0028 0061 0029
249d		<compat> 0028 0062 0029
249e		<compat> 0028 0063 0029
249f		<compat> 0028 0064 0029
24a0		<compat> 0028 0065 0029
24a1		<compat> 0028 0066 0029
24a2		<compat> 0028 0067 0029
24a3		<compat> 0028 0068 0029
24a4		<compat> 0028 0069 0029
24a5		<compat> 0028 006A 0029
24a6		<compat> 0028 006B 0029
24a7		<compat> 0028 006C 0029
24a8		<compat> 0028 006D 0029
24a9		<compat> 0028 006E 0029
24aa		<compat> 0028 006F 0029
24ab		<compat> 0028 0070 0029
24ac		<compat> 0028 0071 0029
24ad		<compat> 0028 0072 0029
24ae		<compat> 0028 0073 0029
24af		<compat> 0028 0074 0029
24b0		<compat> 0028 0075 0029
24b1		<compat> 0028 0076 0029
24b2		<compat> 0028 0077 0029
24b3		<compat> 0028 0078 0029
24b4		<compat> 0028 0079 0029
24b5		<compat> 0028 007A 0029
24b6		<circle> 0041
24b7		<circle> 0042
24b8		<circle> 0043
24b9		<circle> 0044
24ba		<circle> 0045
24bb		<circle> 0046
24bc		<circle> 0047
24bd		<circle> 0048
24be		<circle> 0049
24bf		<circle> 004A
24c0		<circle> 004B
24c1		<circle> 004C
24c2		<circle> 004D
24c3		<circle> 004E
24c4		<circle> 004F
24c5		<circle> 0050
24c6		<circle> 0051
24c7		<circle> 0052
24c8		<circle> 0053
24c9		<circle> 0054
24ca		<circle> 0055
24cb		<circle> 0056
24cc		<circle> 0057
24cd		<circle> 0058
24ce		<circle> 0059
24cf		<circle> 005A
24d0		<circle> 0061
24d1		<circle> 0062
24d2		<circle> 0063
24d3		<circle> 0064
24d4		<circle> 0065
24d5		<circle> 0066
24d6		<circle> 0067
24d7		<circle> 0068
24d8		<circle> 0069
24d9		<circle> 006A
24da		<circle> 006B
24db		<circle> 006C
24dc		<circle> 006D
24dd		<circle> 006E
24de		<circle> 006F
24df		<circle> 0070
24e0		<circle> 0071
24e1		<circle> 0072
24e2		<circle> 0073
24e3		<circle> 0074
24e4		<circle> 0075
24e5		<circle> 0076
24e6		<circle> 0077
24e7		<circle> 0078
24e8		<circle> 0079
24e9		<circle> 007A
24ea		<circle> 0030
2e9f		<compat> 6BCD
2ef3		<compat> 9F9F
2f00		<compat> 4E00
2f01		<compat> 4E28
2f02		<compat> 4E36
2f03		<compat> 4E3F
2f04		<compat> 4E59
2f05		<compat> 4E85
2f06		<compat> 4E8C
2f07		<compat> 4EA0
2f08		<compat> 4EBA
2f09		<compat> 513F
2f0a		<compat> 5165
2f0b		<compat> 516B
2f0c		<compat> 5182
2f0d		<compat> 5196
2f0e		<compat> 51AB
2f0f		<compat> 51E0
2f10		<compat> 51F5
2f11		<compat> 5200
2f12		<compat> 529B
2f13		<compat> 52F9
2f14		<compat> 5315
2f15		<compat> 531A
2f16		<compat> 5338
2f17		<compat> 5341
2f18		<compat> 535C
2f19		<compat> 5369
2f1a		<compat> 5382
2f1b		<compat> 53B6
2f1c		<compat> 53C8
2f1d		<compat> 53E3
2f1e		<compat> 56D7
2f1f		<compat> 571F
2f20		<compat> 58EB
2f21		<compat> 5902
2f22		<compat> 590A
2f23		<compat> 5915
2f24		<compat> 5927
2f25		<compat> 5973
2f26		<compat> 5B50
2f27		<compat> 5B80
2f28		<compat> 5BF8
2f29		<compat> 5C0F
2f2a		<compat> 5C22
2f2b		<compat> 5C38
2f2c		<compat> 5C6E
2f2d		<compat> 5C71
2f2e		<compat> 5DDB
2f2f		<compat> 5DE5
2f30		<compat> 5DF1
2f31		<compat> 5DFE
2f32		<compat> 5E72
2f33		<compat> 5E7A
2f34		<compat> 5E7F
2f35		<compat> 5EF4
2f36		<compat> 5EFE
2f37		<compat> 5F0B
2f38		<compat> 5F13
2f39		<compat> 5F50
2f3a		<compat> 5F61
2f3b		<compat> 5F73
2f3c		<compat> 5FC3
2f3d		<compat> 6208
2f3e		<compat> 6236
2f3f		<compat> 624B
2f40		<compat> 652F
2f41		<compat> 6534
2f42		<compat> 6587
2f43		<compat> 6597
2f44		<compat> 65A4
2f45		<compat> 65B9
2f46		<compat> 65E0
2f47		<compat> 65E5
2f48		<compat> 66F0
2f49		<compat> 6708
2f4a		<compat> 6728
2f4b		<compat> 6B20
2f4c		<compat> 6B62
2f4d		<compat> 6B79
2f4e		<compat> 6BB3
2f4f		<compat> 6BCB
2f50		<compat> 6BD4
2f51		<compat> 6BDB
2f52		<compat> 6C0F
2f53		<compat> 6C14
2f54		<compat> 6C34
2f55		<compat> 706B
2f56		<compat> 722A
2f57		<compat> 7236
2f58		<compat> 723B
2f59		<compat> 723F
2f5a		<compat> 7247
2f5b		<compat> 7259
2f5c		<compat> 725B
2f5d		<compat> 72AC
2f5e		<compat> 7384
2f5f		<compat> 7389
2f60		<compat> 74DC
2f61		<compat> 74E6
2f62		<compat> 7518
2f63		<compat> 751F
2f64		<compat> 7528
2f65		<compat> 7530
2f66		<compat> 758B
2f67		<compat> 7592
2f68		<compat> 7676
2f69		<compat> 767D
2f6a		<compat> 76AE
2f6b		<compat> 76BF
2f6c		<compat> 76EE
2f6d		<compat> 77DB
2f6e		<compat> 77E2
2f6f		<compat> 77F3
2f70		<compat> 793A
2f71		<compat> 79B8
2f72		<compat> 79BE
2f73		<compat> 7A74
2f74		<compat> 7ACB
2f75		<compat> 7AF9
2f76		<compat> 7C73
2f77		<compat> 7CF8
2f78		<compat> 7F36
2f79		<compat> 7F51
2f7a		<compat> 7F8A
2f7b		<compat> 7FBD
2f7c		<compat> 8001
2f7d		<compat> 800C
2f7e		<compat> 8012
2f7f		<compat> 8033
2f80		<compat> 807F
2f81		<compat> 8089
2f82		<compat> 81E3
2f83		<compat> 81EA
2f84		<compat> 81F3
2f85		<compat> 81FC
2f86		<compat> 820C
2f87		<compat> 821B
2f88		<compat> 821F
2f89		<compat> 826E
2f8a		<compat> 8272
2f8b		<compat> 8278
2f8c		<compat> 864D
2f8d		<compat> 866B
2f8e		<compat> 8840
2f8f		<compat> 884C
2f90		<compat> 8863
2f91		<compat> 897E
2f92		<compat> 898B
2f93		<compat> 89D2
2f94		<compat> 8A00
2f95		<compat> 8C37
2f96		<compat> 8C46
2f97		<compat> 8C55
2f98		<compat> 8C78
2f99		<compat> 8C9D
2f9a		<compat> 8D64
2f9b		<compat> 8D70
2f9c		<compat> 8DB3
2f9d		<compat> 8EAB
2f9e		<compat> 8ECA
2f9f		<compat> 8F9B
2fa0		<compat> 8FB0
2fa1		<compat> 8FB5
2fa2		<compat> 9091
2fa3		<compat> 9149
2fa4		<compat> 91C6
2fa5		<compat> 91CC
2fa6		<compat> 91D1
2fa7		<compat> 9577
2fa8		<compat> 9580
2fa9		<compat> 961C
2faa		<compat> 96B6
2fab		<compat> 96B9
2fac		<compat> 96E8
2fad		<compat> 9751
2fae		<compat> 975E
2faf		<compat> 9762
2fb0		<compat> 9769
2fb1		<compat> 97CB
2fb2		<compat> 97ED
2fb3		<compat> 97F3
2fb4		<compat> 9801
2fb5		<compat> 98A8
2fb6		<compat> 98DB
2fb7		<compat> 98DF
2fb8		<compat> 9996
2fb9		<compat> 9999
2fba		<compat> 99AC
2fbb		<compat> 9AA8
2fbc		<compat> 9AD8
2fbd		<compat> 9ADF
2fbe		<compat> 9B25
2fbf		<compat> 9B2F
2fc0		<compat> 9B32
2fc1		<compat> 9B3C
2fc2		<compat> 9B5A
2fc3		<compat> 9CE5
2fc4		<compat> 9E75
2fc5		<compat> 9E7F
2fc6		<compat> 9EA5
2fc7		<compat> 9EBB
2fc8		<compat> 9EC3
2fc9		<compat> 9ECD
2fca		<compat> 9ED1
2fcb		<compat> 9EF9
2fcc		<compat> 9EFD
2fcd		<compat> 9F0E
2fce		<compat> 9F13
2fcf		<compat> 9F20
2fd0		<compat> 9F3B
2fd1		<compat> 9F4A
2fd2		<compat> 9F52
2fd3		<compat> 9F8D
2fd4		<compat> 9F9C
2fd5		<compat> 9FA0
3000		<wide> 0020
3036		<compat> 3012
3038		<compat> 5341
3039		<compat> 5344
303a		<compat> 5345
304c		304B 3099
304e		304D 3099
3050		304F 3099
3052		3051 3099
3054		3053 3099
3056		3055 3099
3058		3057 3099
305a		3059 3099
305c		305B 3099
305e		305D 3099
3060		305F 3099
3062		3061 3099
3065		3064 3099
3067		3066 3099
3069		3068 3099
3070		306F 3099
3071		306F 309A
3073		3072 3099
3074		3072 309A
3076		3075 3099
3077		3075 309A
3079		3078 3099
307a		3078 309A
307c		307B 3099
307d		307B 309A
3094		3046 3099
309b		<compat> 0020 3099
309c		<compat> 0020 309A
309e		309D 3099
30ac		30AB 3099
30ae		30AD 3099
30b0		30AF 3099
30b2		30B1 3099
30b4		30B3 3099
30b6		30B5 3099
30b8		30B7 3099
30ba		30B9 3099
30bc		30BB 3099
30be		30BD 3099
30c0		30BF 3099
30c2		30C1 3099
30c5		30C4 3099
30c7		30C6 3099
30c9		30C8 3099
30d0		30CF 3099
30d1		30CF 309A
30d3		30D2 3099
30d4		30D2 309A
30d6		30D5 3099
30d7		30D5 309A
30d9		30D8 3099
30da		30D8 309A
30dc		30DB 3099
30dd		30DB 309A
30f4		30A6 3099
30f7		30EF 3099
30f8		30F0 3099
30f9		30F1 3099
30fa		30F2 3099
30fe		30FD 3099
3131		<compat> 1100
3132		<compat> 1101
3133		<compat> 11AA
3134		<compat> 1102
3135		<compat> 11AC
3136		<compat> 11AD
3137		<compat> 1103
3138		<compat> 1104
3139		<compat> 1105
313a		<compat> 11B0
313b		<compat> 11B1
313c		<compat> 11B2
313d		<compat> 11B3
313e		<compat> 11B4
313f		<compat> 11B5
3140		<compat> 111A
3141		<compat> 1106
3142		<compat> 1107
3143		<compat> 1108
3144		<compat> 1121
3145		<compat> 1109
3146		<compat> 110A
3147		<compat> 110B
3148		<compat> 110C
3149		<compat> 110D
314a		<compat> 110E
314b		<compat> 110F
314c		<compat> 1110
314d		<compat> 1111
314e		<compat> 1112
314f		<compat> 1161
3150		<compat> 1162
3151		<compat> 1163
3152		<compat> 1164
3153		<compat> 1165
3154		<compat> 1166
3155		<compat> 1167
3156		<compat> 1168
3157		<compat> 1169
3158		<compat> 116A
3159		<compat> 116B
315a		<compat> 116C
315b		<compat> 116D
315c		<compat> 116E
315d		<compat> 116F
315e		<compat> 1170
315f		<compat> 1171
3160		<compat> 1172
3161		<compat> 1173
3162		<compat> 1174
3163		<compat> 1175
3164		<compat> 1160
3165		<compat> 1114
3166		<compat> 1115
3167		<compat> 11C7
3168		<compat> 11C8
3169		<compat> 11CC
316a		<compat> 11CE
316b		<compat> 11D3
316c		<compat> 11D7
316d		<compat> 11D9
316e		<compat> 111C
316f		<compat> 11DD
3170		<compat> 11DF
3171		<compat> 111D
3172		<compat> 111E
3173		<compat> 1120
3174		<compat> 1122
3175		<compat> 1123
3176		<compat> 1127
3177		<compat> 1129
3178		<compat> 112B
3179		<compat> 112C
317a		<compat> 112D
317b		<compat> 112E
317c		<compat> 112F
317d		<compat> 1132
317e		<compat> 1136
317f		<compat> 1140
3180		<compat> 1147
3181		<compat> 114C
3182		<compat> 11F1
3183		<compat> 11F2
3184		<compat> 1157
3185		<compat> 1158
3186		<compat> 1159
3187		<compat> 1184
3188		<compat> 1185
3189		<compat> 1188
318a		<compat> 1191
318b		<compat> 1192
318c		<compat> 1194
318d		<compat> 119E
318e		<compat> 11A1
3192		<super> 4E00
3193		<super> 4E8C
3194		<super> 4E09
3195		<super> 56DB
3196		<super> 4E0A
3197		<super> 4E2D
3198		<super> 4E0B
3199		<super> 7532
319a		<super> 4E59
319b		<super> 4E19
319c		<super> 4E01
319d		<super> 5929
319e		<super> 5730
319f		<super> 4EBA
3200		<compat> 0028 1100 0029
3201		<compat> 0028 1102 0029
3202		<compat> 0028 1103 0029
3203		<compat> 0028 1105 0029
3204		<compat> 0028 1106 0029
3205		<compat> 0028 1107 0029
3206		<compat> 0028 1109 0029
3207		<compat> 0028 110B 0029
3208		<compat> 0028 110C 0029
3209		<compat> 0028 110E 0029
320a		<compat> 0028 110F 0029
320b		<compat> 0028 1110 0029
320c		<compat> 0028 1111 0029
320d		<compat> 0028 1112 0029
320e		<compat> 0028 1100 1161 0029
320f		<compat> 0028 1102 1161 0029
3210		<compat> 0028 1103 1161 0029
3211		<compat> 0028 1105 1161 0029
3212		<compat> 0028 1106 1161 0029
3213		<compat> 0028 1107 1161 0029
3214		<compat> 0028 1109 1161 0029
3215		<compat> 0028 110B 1161 0029
3216		<compat> 0028 110C 1161 0029
3217		<compat> 0028 110E 1161 0029
3218		<compat> 0028 110F 1161 0029
3219		<compat> 0028 1110 1161 0029
321a		<compat> 0028 1111 1161 0029
321b		<compat> 0028 1112 1161 0029
321c		<compat> 0028 110C 116E 0029
3220		<compat> 0028 4E00 0029
3221		<compat> 0028 4E8C 0029
3222		<compat> 0028 4E09 0029
3223		<compat> 0028 56DB 0029
3224		<compat> 0028 4E94 0029
3225		<compat> 0028 516D 0029
3226		<compat> 0028 4E03 0029
3227		<compat> 0028 516B 0029
3228		<compat> 0028 4E5D 0029
3229		<compat> 0028 5341 0029
322a		<compat> 0028 6708 0029
322b		<compat> 0028 706B 0029
322c		<compat> 0028 6C34 0029
322d		<compat> 0028 6728 0029
322e		<compat> 0028 91D1 0029
322f		<compat> 0028 571F 0029
3230		<compat> 0028 65E5 0029
3231		<compat> 0028 682A 0029
3232		<compat> 0028 6709 0029
3233		<compat> 0028 793E 0029
3234		<compat> 0028 540D 0029
3235		<compat> 0028 7279 0029
3236		<compat> 0028 8CA1 0029
3237		<compat> 0028 795D 0029
3238		<compat> 0028 52B4 0029
3239		<compat> 0028 4EE3 0029
323a		<compat> 0028 547C 0029
323b		<compat> 0028 5B66 0029
323c		<compat> 0028 76E3 0029
323d		<compat> 0028 4F01 0029
323e		<compat> 0028 8CC7 0029
323f		<compat> 0028 5354 0029
3240		<compat> 0028 796D 0029
3241		<compat> 0028 4F11 0029
3242		<compat> 0028 81EA 0029
3243		<compat> 0028 81F3 0029
3260		<circle> 1100
3261		<circle> 1102
3262		<circle> 1103
3263		<circle> 1105
3264		<circle> 1106
3265		<circle> 1107
3266		<circle> 1109
3267		<circle> 110B
3268		<circle> 110C
3269		<circle> 110E
326a		<circle> 110F
326b		<circle> 1110
326c		<circle> 1111
326d		<circle> 1112
326e		<circle> 1100 1161
326f		<circle> 1102 1161
3270		<circle> 1103 1161
3271		<circle> 1105 1161
3272		<circle> 1106 1161
3273		<circle> 1107 1161
3274		<circle> 1109 1161
3275		<circle> 110B 1161
3276		<circle> 110C 1161
3277		<circle> 110E 1161
3278		<circle> 110F 1161
3279		<circle> 1110 1161
327a		<circle> 1111 1161
327b		<circle> 1112 1161
3280		<circle> 4E00
3281		<circle> 4E8C
3282		<circle> 4E09
3283		<circle> 56DB
3284		<circle> 4E94
3285		<circle> 516D
3286		<circle> 4E03
3287		<circle> 516B
3288		<circle> 4E5D
3289		<circle> 5341
328a		<circle> 6708
328b		<circle> 706B
328c		<circle> 6C34
328d		<circle> 6728
328e		<circle> 91D1
328f		<circle> 571F
3290		<circle> 65E5
3291		<circle> 682A
3292		<circle> 6709
3293		<circle> 793E
3294		<circle> 540D
3295		<circle> 7279
3296		<circle> 8CA1
3297		<circle> 795D
3298		<circle> 52B4
3299		<circle> 79D8
329a		<circle> 7537
329b		<circle> 5973
329c		<circle> 9069
329d		<circle> 512A
329e		<circle> 5370
329f		<circle> 6CE8
32a0		<circle> 9805
32a1		<circle> 4F11
32a2		<circle> 5199
32a3		<circle> 6B63
32a4		<circle> 4E0A
32a5		<circle> 4E2D
32a6		<circle> 4E0B
32a7		<circle> 5DE6
32a8		<circle> 53F3
32a9		<circle> 533B
32aa		<circle> 5B97
32ab		<circle> 5B66
32ac		<circle> 76E3
32ad		<circle> 4F01
32ae		<circle> 8CC7
32af		<circle> 5354
32b0		<circle> 591C
32c0		<compat> 0031 6708
32c1		<compat> 0032 6708
32c2		<compat> 0033 6708
32c3		<compat> 0034 6708
32c4		<compat> 0035 6708
32c5		<compat> 0036 6708
32c6		<compat> 0037 6708
32c7		<compat> 0038 6708
32c8		<compat> 0039 6708
32c9		<compat> 0031 0030 6708
32ca		<compat> 0031 0031 6708
32cb		<compat> 0031 0032 6708
32d0		<circle> 30A2
32d1		<circle> 30A4
32d2		<circle> 30A6
32d3		<circle> 30A8
32d4		<circle> 30AA
32d5		<circle> 30AB
32d6		<circle> 30AD
32d7		<circle> 30AF
32d8		<circle> 30B1
32d9		<circle> 30B3
32da		<circle> 30B5
32db		<circle> 30B7
32dc		<circle> 30B9
32dd		<circle> 30BB
32de		<circle> 30BD
32df		<circle> 30BF
32e0		<circle> 30C1
32e1		<circle> 30C4
32e2		<circle> 30C6
32e3		<circle> 30C8
32e4		<circle> 30CA
32e5		<circle> 30CB
32e6		<circle> 30CC
32e7		<circle> 30CD
32e8		<circle> 30CE
32e9		<circle> 30CF
32ea		<circle> 30D2
32eb		<circle> 30D5
32ec		<circle> 30D8
32ed		<circle> 30DB
32ee		<circle> 30DE
32ef		<circle> 30DF
32f0		<circle> 30E0
32f1		<circle> 30E1
32f2		<circle> 30E2
32f3		<circle> 30E4
32f4		<circle> 30E6
32f5		<circle> 30E8
32f6		<circle> 30E9
32f7		<circle> 30EA
32f8		<circle> 30EB
32f9		<circle> 30EC
32fa		<circle> 30ED
32fb		<circle> 30EF
32fc		<circle> 30F0
32fd		<circle> 30F1
32fe		<circle> 30F2
3300		<square> 30A2 30D1 30FC 30C8
3301		<square> 30A2 30EB 30D5 30A1
3302		<square> 30A2 30F3 30DA 30A2
3303		<square> 30A2 30FC 30EB
3304		<square> 30A4 30CB 30F3 30B0
3305		<square> 30A4 30F3 30C1
3306		<square> 30A6 30A9 30F3
3307		<square> 30A8 30B9 30AF 30FC 30C9
3308		<square> 30A8 30FC 30AB 30FC
3309		<square> 30AA 30F3 30B9
330a		<square> 30AA 30FC 30E0
330b		<square> 30AB 30A4 30EA
330c		<square> 30AB 30E9 30C3 30C8
330d		<square> 30AB 30ED 30EA 30FC
330e		<square> 30AC 30ED 30F3
330f		<square> 30AC 30F3 30DE
3310		<square> 30AE 30AC
3311		<square> 30AE 30CB 30FC
3312		<square> 30AD 30E5 30EA 30FC
3313		<square> 30AE 30EB 30C0 30FC
3314		<square> 30AD 30ED
3315		<square> 30AD 30ED 30B0 30E9 30E0
3316		<square> 30AD 30ED 30E1 30FC 30C8 30EB
3317		<square> 30AD 30ED 30EF 30C3 30C8
3318		<square> 30B0 30E9 30E0
3319		<square> 30B0 30E9 30E0 30C8 30F3
331a		<square> 30AF 30EB 30BC 30A4 30ED
331b		<square> 30AF 30ED 30FC 30CD
331c		<square> 30B1 30FC 30B9
331d		<square> 30B3 30EB 30CA
331e		<square> 30B3 30FC 30DD
331f		<square> 30B5 30A4 30AF 30EB
3320		<square> 30B5 30F3 30C1 30FC 30E0
3321		<square> 30B7 30EA 30F3 30B0
3322		<square> 30BB 30F3 30C1
3323		<square> 30BB 30F3 30C8
3324		<square> 30C0 30FC 30B9
3325		<square> 30C7 30B7
3326		<square> 30C9 30EB
3327		<square> 30C8 30F3
3328		<square> 30CA 30CE
3329		<square> 30CE 30C3 30C8
332a		<square> 30CF 30A4 30C4
332b		<square> 30D1 30FC 30BB 30F3 30C8
332c		<square> 30D1 30FC 30C4
332d		<square> 30D0 30FC 30EC 30EB
332e		<square> 30D4 30A2 30B9 30C8 30EB
332f		<square> 30D4 30AF 30EB
3330		<square> 30D4 30B3
3331		<square> 30D3 30EB
3332		<square> 30D5 30A1 30E9 30C3 30C9
3333		<square> 30D5 30A3 30FC 30C8
3334		<square> 30D6 30C3 30B7 30A7 30EB
3335		<square> 30D5 30E9 30F3
3336		<square> 30D8 30AF 30BF 30FC 30EB
3337		<square> 30DA 30BD
3338		<square> 30DA 30CB 30D2
3339		<square> 30D8 30EB 30C4
333a		<square> 30DA 30F3 30B9
333b		<square> 30DA 30FC 30B8
333c		<square> 30D9 30FC 30BF
333d		<square> 30DD 30A4 30F3 30C8
333e		<square> 30DC 30EB 30C8
333f		<square> 30DB 30F3
3340		<square> 30DD 30F3 30C9
3341		<square> 30DB 30FC 30EB
3342		<square> 30DB 30FC 30F3
3343		<square> 30DE 30A4 30AF 30ED
3344		<square> 30DE 30A4 30EB
3345		<square> 30DE 30C3 30CF
3346		<square> 30DE 30EB 30AF
3347		<square> 30DE 30F3 30B7 30E7 30F3
3348		<square> 30DF 30AF 30ED 30F3
3349		<square> 30DF 30EA
334a		<square> 30DF 30EA 30D0 30FC 30EB
334b		<square> 30E1 30AC
334c		<square> 30E1 30AC 30C8 30F3
334d		<square> 30E1 30FC 30C8 30EB
334e		<square> 30E4 30FC 30C9
334f		<square> 30E4 30FC 30EB
3350		<square> 30E6 30A2 30F3
3351		<square> 30EA 30C3 30C8 30EB
3352		<square> 30EA 30E9
3353		<square> 30EB 30D4 30FC
3354		<square> 30EB 30FC 30D6 30EB
3355		<square> 30EC 30E0
3356		<square> 30EC 30F3 30C8 30B2 30F3
3357		<square> 30EF 30C3 30C8
3358		<compat> 0030 70B9
3359		<compat> 0031 70B9
335a		<compat> 0032 70B9
335b		<compat> 0033 70B9
335c		<compat> 0034 70B9
335d		<compat> 0035 70B9
335e		<compat> 0036 70B9
335f		<compat> 0037 70B9
3360		<compat> 0038 70B9
3361		<compat> 0039 70B9
3362		<compat> 0031 0030 70B9
3363		<compat> 0031 0031 70B9
3364		<compat> 0031 0032 70B9
3365		<compat> 0031 0033 70B9
3366		<compat> 0031 0034 70B9
3367		<compat> 0031 0035 70B9
3368		<compat> 0031 0036 70B9
3369		<compat> 0031 0037 70B9
336a		<compat> 0031 0038 70B9
336b		<compat> 0031 0039 70B9
336c		<compat> 0032 0030 70B9
336d		<compat> 0032 0031 70B9
336e		<compat> 0032 0032 70B9
336f		<compat> 0032 0033 70B9
3370		<compat> 0032 0034 70B9
3371		<square> 0068 0050 0061
3372		<square> 0064 0061
3373		<square> 0041 0055
3374		<square> 0062 0061 0072
3375		<square> 006F 0056
3376		<square> 0070 0063
337b		<square> 5E73 6210
337c		<square> 662D 548C
337d		<square> 5927 6B63
337e		<square> 660E 6CBB
337f		<square> 682A 5F0F 4F1A 793E
3380		<square> 0070 0041
3381		<square> 006E 0041
3382		<square> 03BC 0041
3383		<square> 006D 0041
3384		<square> 006B 0041
3385		<square> 004B 0042
3386		<square> 004D 0042
3387		<square> 0047 0042
3388		<square> 0063 0061 006C
3389		<square> 006B 0063 0061 006C
338a		<square> 0070 0046
338b		<square> 006E 0046
338c		<square> 03BC 0046
338d		<square> 03BC 0067
338e		<square> 006D 0067
338f		<square> 006B 0067
3390		<square> 0048 007A
3391		<square> 006B 0048 007A
3392		<square> 004D 0048 007A
3393		<square> 0047 0048 007A
3394		<square> 0054 0048 007A
3395		<square> 03BC 2113
3396		<square> 006D 2113
3397		<square> 0064 2113
3398		<square> 006B 2113
3399		<square> 0066 006D
339a		<square> 006E 006D
339b		<square> 03BC 006D
339c		<square> 006D 006D
339d		<square> 0063 006D
339e		<square> 006B 006D
339f		<square> 006D 006D 00B2
33a0		<square> 0063 006D 00B2
33a1		<square> 006D 00B2
33a2		<square> 006B 006D 00B2
33a3		<square> 006D 006D 00B3
33a4		<square> 0063 006D 00B3
33a5		<square> 006D 00B3
33a6		<square> 006B 006D 00B3
33a7		<square> 006D 2215 0073
33a8		<square> 006D 2215 0073 00B2
33a9		<square> 0050 0061
33aa		<square> 006B 0050 0061
33ab		<square> 004D 0050 0061
33ac		<square> 0047 0050 0061
33ad		<square> 0072 0061 0064
33ae		<square> 0072 0061 0064 2215 0073
33af		<square> 0072 0061 0064 2215 0073 00B2
33b0		<square> 0070 0073
33b1		<square> 006E 0073
33b2		<square> 03BC 0073
33b3		<square> 006D 0073
33b4		<square> 0070 0056
33b5		<square> 006E 0056
33b6		<square> 03BC 0056
33b7		<square> 006D 0056
33b8		<square> 006B 0056
33b9		<square> 004D 0056
33ba		<square> 0070 0057
33bb		<square> 006E 0057
33bc		<square> 03BC 0057
33bd		<square> 006D 0057
33be		<square> 006B 0057
33bf		<square> 004D 0057
33c0		<square> 006B 03A9
33c1		<square> 004D 03A9
33c2		<square> 0061 002E 006D 002E
33c3		<square> 0042 0071
33c4		<square> 0063 0063
33c5		<square> 0063 0064
33c6		<square> 0043 2215 006B 0067
33c7		<square> 0043 006F 002E
33c8		<square> 0064 0042
33c9		<square> 0047 0079
33ca		<square> 0068 0061
33cb		<square> 0048 0050
33cc		<square> 0069 006E
33cd		<square> 004B 004B
33ce		<square> 004B 004D
33cf		<square> 006B 0074
33d0		<square> 006C 006D
33d1		<square> 006C 006E
33d2		<square> 006C 006F 0067
33d3		<square> 006C 0078
33d4		<square> 006D 0062
33d5		<square> 006D 0069 006C
33d6		<square> 006D 006F 006C
33d7		<square> 0050 0048
33d8		<square> 0070 002E 006D 002E
33d9		<square> 0050 0050 004D
33da		<square> 0050 0052
33db		<square> 0073 0072
33dc		<square> 0053 0076
33dd		<square> 0057 0062
33e0		<compat> 0031 65E5
33e1		<compat> 0032 65E5
33e2		<compat> 0033 65E5
33e3		<compat> 0034 65E5
33e4		<compat> 0035 65E5
33e5		<compat> 0036 65E5
33e6		<compat> 0037 65E5
33e7		<compat> 0038 65E5
33e8		<compat> 0039 65E5
33e9		<compat> 0031 0030 65E5
33ea		<compat> 0031 0031 65E5
33eb		<compat> 0031 0032 65E5
33ec		<compat> 0031 0033 65E5
33ed		<compat> 0031 0034 65E5
33ee		<compat> 0031 0035 65E5
33ef		<compat> 0031 0036 65E5
33f0		<compat> 0031 0037 65E5
33f1		<compat> 0031 0038 65E5
33f2		<compat> 0031 0039 65E5
33f3		<compat> 0032 0030 65E5
33f4		<compat> 0032 0031 65E5
33f5		<compat> 0032 0032 65E5
33f6		<compat> 0032 0033 65E5
33f7		<compat> 0032 0034 65E5
33f8		<compat> 0032 0035 65E5
33f9		<compat> 0032 0036 65E5
33fa		<compat> 0032 0037 65E5
33fb		<compat> 0032 0038 65E5
33fc		<compat> 0032 0039 65E5
33fd		<compat> 0033 0030 65E5
33fe		<compat> 0033 0031 65E5
f900		8C48
f901		66F4
f902		8ECA
f903		8CC8
f904		6ED1
f905		4E32
f906		53E5
f907	f908	9F9C
f909		5951
f90a		91D1
f90b		5587
f90c		5948
f90d		61F6
f90e		7669
f90f		7F85
f910		863F
f911		87BA
f912		88F8
f913		908F
f914		6A02
f915		6D1B
f916		70D9
f917		73DE
f918		843D
f919		916A
f91a		99F1
f91b		4E82
f91c		5375
f91d		6B04
f91e		721B
f91f		862D
f920		9E1E
f921		5D50
f922		6FEB
f923		85CD
f924		8964
f925		62C9
f926		81D8
f927		881F
f928		5ECA
f929		6717
f92a		6D6A
f92b		72FC
f92c		90CE
f92d		4F86
f92e		51B7
f92f		52DE
f930		64C4
f931		6AD3
f932		7210
f933		76E7
f934		8001
f935		8606
f936		865C
f937		8DEF
f938		9732
f939		9B6F
f93a		9DFA
f93b		788C
f93c		797F
f93d		7DA0
f93e		83C9
f93f		9304
f940		9E7F
f941		8AD6
f942		58DF
f943		5F04
f944		7C60
f945		807E
f946		7262
f947		78CA
f948		8CC2
f949		96F7
f94a		58D8
f94b		5C62
f94c		6A13
f94d		6DDA
f94e		6F0F
f94f		7D2F
f950		7E37
f951		96FB
f952		52D2
f953		808B
f954		51DC
f955		51CC
f956		7A1C
f957		7DBE
f958		83F1
f959		9675
f95a		8B80
f95b		62CF
f95c		6A02
f95d		8AFE
f95e		4E39
f95f		5BE7
f960		6012
f961		7387
f962		7570
f963		5317
f964		78FB
f965		4FBF
f966		5FA9
f967		4E0D
f968		6CCC
f969		6578
f96a		7D22
f96b		53C3
f96c		585E
f96d		7701
f96e		8449
f96f		8AAA
f970		6BBA
f971		8FB0
f972		6C88
f973		62FE
f974		82E5
f975		63A0
f976		7565
f977		4EAE
f978		5169
f979		51C9
f97a		6881
f97b		7CE7
f97c		826F
f97d		8AD2
f97e		91CF
f97f		52F5
f980		5442
f981		5973
f982		5EEC
f983		65C5
f984		6FFE
f985		792A
f986		95AD
f987		9A6A
f988		9E97
f989		9ECE
f98a		529B
f98b		66C6
f98c		6B77
f98d		8F62
f98e		5E74
f98f		6190
f990		6200
f991		649A
f992		6F23
f993		7149
f994		7489
f995		79CA
f996		7DF4
f997		806F
f998		8F26
f999		84EE
f99a		9023
f99b		934A
f99c		5217
f99d		52A3
f99e		54BD
f99f		70C8
f9a0		88C2
f9a1		8AAA
f9a2		5EC9
f9a3		5FF5
f9a4		637B
f9a5		6BAE
f9a6		7C3E
f9a7		7375
f9a8		4EE4
f9a9		56F9
f9aa		5BE7
f9ab		5DBA
f9ac		601C
f9ad		73B2
f9ae		7469
f9af		7F9A
f9b0		8046
f9b1		9234
f9b2		96F6
f9b3		9748
f9b4		9818
f9b5		4F8B
f9b6		79AE
f9b7		91B4
f9b8		96B8
f9b9		60E1
f9ba		4E86
f9bb		50DA
f9bc		5BEE
f9bd		5C3F
f9be		6599
f9bf		6A02
f9c0		71CE
f9c1		7642
f9c2		84FC
f9c3		907C
f9c4		9F8D
f9c5		6688
f9c6		962E
f9c7		5289
f9c8		677B
f9c9		67F3
f9ca		6D41
f9cb		6E9C
f9cc		7409
f9cd		7559
f9ce		786B
f9cf		7D10
f9d0		985E
f9d1		516D
f9d2		622E
f9d3		9678
f9d4		502B
f9d5		5D19
f9d6		6DEA
f9d7		8F2A
f9d8		5F8B
f9d9		6144
f9da		6817
f9db		7387
f9dc		9686
f9dd		5229
f9de		540F
f9df		5C65
f9e0		6613
f9e1		674E
f9e2		68A8
f9e3		6CE5
f9e4		7406
f9e5		75E2
f9e6		7F79
f9e7		88CF
f9e8		88E1
f9e9		91CC
f9ea		96E2
f9eb		533F
f9ec		6EBA
f9ed		541D
f9ee		71D0
f9ef		7498
f9f0		85FA
f9f1		96A3
f9f2		9C57
f9f3		9E9F
f9f4		6797
f9f5		6DCB
f9f6		81E8
f9f7		7ACB
f9f8		7B20
f9f9		7C92
f9fa		72C0
f9fb		7099
f9fc		8B58
f9fd		4EC0
f9fe		8336
f9ff		523A
fa00		5207
fa01		5EA6
fa02		62D3
fa03		7CD6
fa04		5B85
fa05		6D1E
fa06		66B4
fa07		8F3B
fa08		884C
fa09		964D
fa0a		898B
fa0b		5ED3
fa0c		5140
fa0d		55C0
fa10		585A
fa12		6674
fa15		51DE
fa16		732A
fa17		76CA
fa18		793C
fa19		795E
fa1a		7965
fa1b		798F
fa1c		9756
fa1d		7CBE
fa1e		7FBD
fa20		8612
fa22		8AF8
fa25		9038
fa26		90FD
fa2a		98EF
fa2b		98FC
fa2c		9928
fa2d		9DB4
fb00		<compat> 0066 0066
fb01		<compat> 0066 0069
fb02		<compat> 0066 006C
fb03		<compat> 0066 0066 0069
fb04		<compat> 0066 0066 006C
fb05		<compat> 017F 0074
fb06		<compat> 0073 0074
fb13		<compat> 0574 0576
fb14		<compat> 0574 0565
fb15		<compat> 0574 056B
fb16		<compat> 057E 0576
fb17		<compat> 0574 056D
fb1d		05D9 05B4
fb1f		05F2 05B7
fb20		<font> 05E2
fb21		<font> 05D0
fb22		<font> 05D3
fb23		<font> 05D4
fb24		<font> 05DB
fb25		<font> 05DC
fb26		<font> 05DD
fb27		<font> 05E8
fb28		<font> 05EA
fb29		<font> 002B
fb2a		05E9 05C1
fb2b		05E9 05C2
fb2c		FB49 05C1
fb2d		FB49 05C2
fb2e		05D0 05B7
fb2f		05D0 05B8
fb30		05D0 05BC
fb31		05D1 05BC
fb32		05D2 05BC
fb33		05D3 05BC
fb34		05D4 05BC
fb35		05D5 05BC
fb36		05D6 05BC
fb38		05D8 05BC
fb39		05D9 05BC
fb3a		05DA 05BC
fb3b		05DB 05BC
fb3c		05DC 05BC
fb3e		05DE 05BC
fb40		05E0 05BC
fb41		05E1 05BC
fb43		05E3 05BC
fb44		05E4 05BC
fb46		05E6 05BC
fb47		05E7 05BC
fb48		05E8 05BC
fb49		05E9 05BC
fb4a		05EA 05BC
fb4b		05D5 05B9
fb4c		05D1 05BF
fb4d		05DB 05BF
fb4e		05E4 05BF
fb4f		<compat> 05D0 05DC
fb50		<isolated> 0671
fb51		<final> 0671
fb52		<isolated> 067B
fb53		<final> 067B
fb54		<initial> 067B
fb55		<medial> 067B
fb56		<isolated> 067E
fb57		<final> 067E
fb58		<initial> 067E
fb59		<medial> 067E
fb5a		<isolated> 0680
fb5b		<final> 0680
fb5c		<initial> 0680
fb5d		<medial> 0680
fb5e		<isolated> 067A
fb5f		<final> 067A
fb60		<initial> 067A
fb61		<medial> 067A
fb62		<isolated> 067F
fb63		<final> 067F
fb64		<initial> 067F
fb65		<medial> 067F
fb66		<isolated> 0679
fb67		<final> 0679
fb68		<initial> 0679
fb69		<medial> 0679
fb6a		<isolated> 06A4
fb6b		<final> 06A4
fb6c		<initial> 06A4
fb6d		<medial> 06A4
fb6e		<isolated> 06A6
fb6f		<final> 06A6
fb70		<initial> 06A6
fb71		<medial> 06A6
fb72		<isolated> 0684
fb73		<final> 0684
fb74		<initial> 0684
fb75		<medial> 0684
fb76		<isolated> 0683
fb77		<final> 0683
fb78		<initial> 0683
fb79		<medial> 0683
fb7a		<isolated> 0686
fb7b		<final> 0686
fb7c		<initial> 0686
fb7d		<medial> 0686
fb7e		<isolated> 0687
fb7f		<final> 0687
fb80		<initial> 0687
fb81		<medial> 0687
fb82		<isolated> 068D
fb83		<final> 068D
fb84		<isolated> 068C
fb85		<final> 068C
fb86		<isolated> 068E
fb87		<final> 068E
fb88		<isolated> 0688
fb89		<final> 0688
fb8a		<isolated> 0698
fb8b		<final> 0698
fb8c		<isolated> 0691
fb8d		<final> 0691
fb8e		<isolated> 06A9
fb8f		<final> 06A9
fb90		<initial> 06A9
fb91		<medial> 06A9
fb92		<isolated> 06AF
fb93		<final> 06AF
fb94		<initial> 06AF
fb95		<medial> 06AF
fb96		<isolated> 06B3
fb97		<final> 06B3
fb98		<initial> 06B3
fb99		<medial> 06B3
fb9a		<isolated> 06B1
fb9b		<final> 06B1
fb9c		<initial> 06B1
fb9d		<medial> 06B1
fb9e		<isolated> 06BA
fb9f		<final> 06BA
fba0		<isolated> 06BB
fba1		<final> 06BB
fba2		<initial> 06BB
fba3		<medial> 06BB
fba4		<isolated> 06C0
fba5		<final> 06C0
fba6		<isolated> 06C1
fba7		<final> 06C1
fba8		<initial> 06C1
fba9		<medial> 06C1
fbaa		<isolated> 06BE
fbab		<final> 06BE
fbac		<initial> 06BE
fbad		<medial> 06BE
fbae		<isolated> 06D2
fbaf		<final> 06D2
fbb0		<isolated> 06D3
fbb1		<final> 06D3
fbd3		<isolated> 06AD
fbd4		<final> 06AD
fbd5		<initial> 06AD
fbd6		<medial> 06AD
fbd7		<isolated> 06C7
fbd8		<final> 06C7
fbd9		<isolated> 06C6
fbda		<final> 06C6
fbdb		<isolated> 06C8
fbdc		<final> 06C8
fbdd		<isolated> 0677
fbde		<isolated> 06CB
fbdf		<final> 06CB
fbe0		<isolated> 06C5
fbe1		<final> 06C5
fbe2		<isolated> 06C9
fbe3		<final> 06C9
fbe4		<isolated> 06D0
fbe5		<final> 06D0
fbe6		<initial> 06D0
fbe7		<medial> 06D0
fbe8		<initial> 0649
fbe9		<medial> 0649
fbea		<isolated> 0626 0627
fbeb		<final> 0626 0627
fbec		<isolated> 0626 06D5
fbed		<final> 0626 06D5
fbee		<isolated> 0626 0648
fbef		<final> 0626 0648
fbf0		<isolated> 0626 06C7
fbf1		<final> 0626 06C7
fbf2		<isolated> 0626 06C6
fbf3		<final> 0626 06C6
fbf4		<isolated> 0626 06C8
fbf5		<final> 0626 06C8
fbf6		<isolated> 0626 06D0
fbf7		<final> 0626 06D0
fbf8		<initial> 0626 06D0
fbf9		<isolated> 0626 0649
fbfa		<final> 0626 0649
fbfb		<initial> 0626 0649
fbfc		<isolated> 06CC
fbfd		<final> 06CC
fbfe		<initial> 06CC
fbff		<medial> 06CC
fc00		<isolated> 0626 062C
fc01		<isolated> 0626 062D
fc02		<isolated> 0626 0645
fc03		<isolated> 0626 0649
fc04		<isolated> 0626 064A
fc05		<isolated> 0628 062C
fc06		<isolated> 0628 062D
fc07		<isolated> 0628 062E
fc08		<isolated> 0628 0645
fc09		<isolated> 0628 0649
fc0a		<isolated> 0628 064A
fc0b		<isolated> 062A 062C
fc0c		<isolated> 062A 062D
fc0d		<isolated> 062A 062E
fc0e		<isolated> 062A 0645
fc0f		<isolated> 062A 0649
fc10		<isolated> 062A 064A
fc11		<isolated> 062B 062C
fc12		<isolated> 062B 0645
fc13		<isolated> 062B 0649
fc14		<isolated> 062B 064A
fc15		<isolated> 062C 062D
fc16		<isolated> 062C 0645
fc17		<isolated> 062D 062C
fc18		<isolated> 062D 0645
fc19		<isolated> 062E 062C
fc1a		<isolated> 062E 062D
fc1b		<isolated> 062E 0645
fc1c		<isolated> 0633 062C
fc1d		<isolated> 0633 062D
fc1e		<isolated> 0633 062E
fc1f		<isolated> 0633 0645
fc20		<isolated> 0635 062D
fc21		<isolated> 0635 0645
fc22		<isolated> 0636 062C
fc23		<isolated> 0636 062D
fc24		<isolated> 0636 062E
fc25		<isolated> 0636 0645
fc26		<isolated> 0637 062D
fc27		<isolated> 0637 0645
fc28		<isolated> 0638 0645
fc29		<isolated> 0639 062C
fc2a		<isolated> 0639 0645
fc2b		<isolated> 063A 062C
fc2c		<isolated> 063A 0645
fc2d		<isolated> 0641 062C
fc2e		<isolated> 0641 062D
fc2f		<isolated> 0641 062E
fc30		<isolated> 0641 0645
fc31		<isolated> 0641 0649
fc32		<isolated> 0641 064A
fc33		<isolated> 0642 062D
fc34		<isolated> 0642 0645
fc35		<isolated> 0642 0649
fc36		<isolated> 0642 064A
fc37		<isolated> 0643 0627
fc38		<isolated> 0643 062C
fc39		<isolated> 0643 062D
fc3a		<isolated> 0643 062E
fc3b		<isolated> 0643 0644
fc3c		<isolated> 0643 0645
fc3d		<isolated> 0643 0649
fc3e		<isolated> 0643 064A
fc3f		<isolated> 0644 062C
fc40		<isolated> 0644 062D
fc41		<isolated> 0644 062E
fc42		<isolated> 0644 0645
fc43		<isolated> 0644 0649
fc44		<isolated> 0644 064A
fc45		<isolated> 0645 062C
fc46		<isolated> 0645 062D
fc47		<isolated> 0645 062E
fc48		<isolated> 0645 0645
fc49		<isolated> 0645 0649
fc4a		<isolated> 0645 064A
fc4b		<isolated> 0646 062C
fc4c		<isolated> 0646 062D
fc4d		<isolated> 0646 062E
fc4e		<isolated> 0646 0645
fc4f		<isolated> 0646 0649
fc50		<isolated> 0646 064A
fc51		<isolated> 0647 062C
fc52		<isolated> 0647 0645
fc53		<isolated> 0647 0649
fc54		<isolated> 0647 064A
fc55		<isolated> 064A 062C
fc56		<isolated> 064A 062D
fc57		<isolated> 064A 062E
fc58		<isolated> 064A 0645
fc59		<isolated> 064A 0649
fc5a		<isolated> 064A 064A
fc5b		<isolated> 0630 0670
fc5c		<isolated> 0631 0670
fc5d		<isolated> 0649 0670
fc5e		<isolated> 0020 064C 0651
fc5f		<isolated> 0020 064D 0651
fc60		<isolated> 0020 064E 0651
fc61		<isolated> 0020 064F 0651
fc62		<isolated> 0020 0650 0651
fc63		<isolated> 0020 0651 0670
fc64		<final> 0626 0631
fc65		<final> 0626 0632
fc66		<final> 0626 0645
fc67		<final> 0626 0646
fc68		<final> 0626 0649
fc69		<final> 0626 064A
fc6a		<final> 0628 0631
fc6b		<final> 0628 0632
fc6c		<final> 0628 0645
fc6d		<final> 0628 0646
fc6e		<final> 0628 0649
fc6f		<final> 0628 064A
fc70		<final> 062A 0631
fc71		<final> 062A 0632
fc72		<final> 062A 0645
fc73		<final> 062A 0646
fc74		<final> 062A 0649
fc75		<final> 062A 064A
fc76		<final> 062B 0631
fc77		<final> 062B 0632
fc78		<final> 062B 0645
fc79		<final> 062B 0646
fc7a		<final> 062B 0649
fc7b		<final> 062B 064A
fc7c		<final> 0641 0649
fc7d		<final> 0641 064A
fc7e		<final> 0642 0649
fc7f		<final> 0642 064A
fc80		<final> 0643 0627
fc81		<final> 0643 0644
fc82		<final> 0643 0645
fc83		<final> 0643 0649
fc84		<final> 0643 064A
fc85		<final> 0644 0645
fc86		<final> 0644 0649
fc87		<final> 0644 064A
fc88		<final> 0645 0627
fc89		<final> 0645 0645
fc8a		<final> 0646 0631
fc8b		<final> 0646 0632
fc8c		<final> 0646 0645
fc8d		<final> 0646 0646
fc8e		<final> 0646 0649
fc8f		<final> 0646 064A
fc90		<final> 0649 0670
fc91		<final> 064A 0631
fc92		<final> 064A 0632
fc93		<final> 064A 0645
fc94		<final> 064A 0646
fc95		<final> 064A 0649
fc96		<final> 064A 064A
fc97		<initial> 0626 062C
fc98		<initial> 0626 062D
fc99		<initial> 0626 062E
fc9a		<initial> 0626 0645
fc9b		<initial> 0626 0647
fc9c		<initial> 0628 062C
fc9d		<initial> 0628 062D
fc9e		<initial> 0628 062E
fc9f		<initial> 0628 0645
fca0		<initial> 0628 0647
fca1		<initial> 062A 062C
fca2		<initial> 062A 062D
fca3		<initial> 062A 062E
fca4		<initial> 062A 0645
fca5		<initial> 062A 0647
fca6		<initial> 062B 0645
fca7		<initial> 062C 062D
fca8		<initial> 062C 0645
fca9		<initial> 062D 062C
fcaa		<initial> 062D 0645
fcab		<initial> 062E 062C
fcac		<initial> 062E 0645
fcad		<initial> 0633 062C
fcae		<initial> 0633 062D
fcaf		<initial> 0633 062E
fcb0		<initial> 0633 0645
fcb1		<initial> 0635 062D
fcb2		<initial> 0635 062E
fcb3		<initial> 0635 0645
fcb4		<initial> 0636 062C
fcb5		<initial> 0636 062D
fcb6		<initial> 0636 062E
fcb7		<initial> 0636 0645
fcb8		<initial> 0637 062D
fcb9		<initial> 0638 0645
fcba		<initial> 0639 062C
fcbb		<initial> 0639 0645
fcbc		<initial> 063A 062C
fcbd		<initial> 063A 0645
fcbe		<initial> 0641 062C
fcbf		<initial> 0641 062D
fcc0		<initial> 0641 062E
fcc1		<initial> 0641 0645
fcc2		<initial> 0642 062D
fcc3		<initial> 0642 0645
fcc4		<initial> 0643 062C
fcc5		<initial> 0643 062D
fcc6		<initial> 0643 062E
fcc7		<initial> 0643 0644
fcc8		<initial> 0643 0645
fcc9		<initial> 0644 062C
fcca		<initial> 0644 062D
fccb		<initial> 0644 062E
fccc		<initial> 0644 0645
fccd		<initial> 0644 0647
fcce		<initial> 0645 062C
fccf		<initial> 0645 062D
fcd0		<initial> 0645 062E
fcd1		<initial> 0645 0645
fcd2		<initial> 0646 062C
fcd3		<initial> 0646 062D
fcd4		<initial> 0646 062E
fcd5		<initial> 0646 0645
fcd6		<initial> 0646 0647
fcd7		<initial> 0647 062C
fcd8		<initial> 0647 0645
fcd9		<initial> 0647 0670
fcda		<initial> 064A 062C
fcdb		<initial> 064A 062D
fcdc		<initial> 064A 062E
fcdd		<initial> 064A 0645
fcde		<initial> 064A 0647
fcdf		<medial> 0626 0645
fce0		<medial> 0626 0647
fce1		<medial> 0628 0645
fce2		<medial> 0628 0647
fce3		<medial> 062A 0645
fce4		<medial> 062A 0647
fce5		<medial> 062B 0645
fce6		<medial> 062B 0647
fce7		<medial> 0633 0645
fce8		<medial> 0633 0647
fce9		<medial> 0634 0645
fcea		<medial> 0634 0647
fceb		<medial> 0643 0644
fcec		<medial> 0643 0645
fced		<medial> 0644 0645
fcee		<medial> 0646 0645
fcef		<medial> 0646 0647
fcf0		<medial> 064A 0645
fcf1		<medial> 064A 0647
fcf2		<medial> 0640 064E 0651
fcf3		<medial> 0640 064F 0651
fcf4		<medial> 0640 0650 0651
fcf5		<isolated> 0637 0649
fcf6		<isolated> 0637 064A
fcf7		<isolated> 0639 0649
fcf8		<isolated> 0639 064A
fcf9		<isolated> 063A 0649
fcfa		<isolated> 063A 064A
fcfb		<isolated> 0633 0649
fcfc		<isolated> 0633 064A
fcfd		<isolated> 0634 0649
fcfe		<isolated> 0634 064A
fcff		<isolated> 062D 0649
fd00		<isolated> 062D 064A
fd01		<isolated> 062C 0649
fd02		<isolated> 062C 064A
fd03		<isolated> 062E 0649
fd04		<isolated> 062E 064A
fd05		<isolated> 0635 0649
fd06		<isolated> 0635 064A
fd07		<isolated> 0636 0649
fd08		<isolated> 0636 064A
fd09		<isolated> 0634 062C
fd0a		<isolated> 0634 062D
fd0b		<isolated> 0634 062E
fd0c		<isolated> 0634 0645
fd0d		<isolated> 0634 0631
fd0e		<isolated> 0633 0631
fd0f		<isolated> 0635 0631
fd10		<isolated> 0636 0631
fd11		<final> 0637 0649
fd12		<final> 0637 064A
fd13		<final> 0639 0649
fd14		<final> 0639 064A
fd15		<final> 063A 0649
fd16		<final> 063A 064A
fd17		<final> 0633 0649
fd18		<final> 0633 064A
fd19		<final> 0634 0649
fd1a		<final> 0634 064A
fd1b		<final> 062D 0649
fd1c		<final> 062D 064A
fd1d		<final> 062C 0649
fd1e		<final> 062C 064A
fd1f		<final> 062E 0649
fd20		<final> 062E 064A
fd21		<final> 0635 0649
fd22		<final> 0635 064A
fd23		<final> 0636 0649
fd24		<final> 0636 064A
fd25		<final> 0634 062C
fd26		<final> 0634 062D
fd27		<final> 0634 062E
fd28		<final> 0634 0645
fd29		<final> 0634 0631
fd2a		<final> 0633 0631
fd2b		<final> 0635 0631
fd2c		<final> 0636 0631
fd2d		<initial> 0634 062C
fd2e		<initial> 0634 062D
fd2f		<initial> 0634 062E
fd30		<initial> 0634 0645
fd31		<initial> 0633 0647
fd32		<initial> 0634 0647
fd33		<initial> 0637 0645
fd34		<medial> 0633 062C
fd35		<medial> 0633 062D
fd36		<medial> 0633 062E
fd37		<medial> 0634 062C
fd38		<medial> 0634 062D
fd39		<medial> 0634 062E
fd3a		<medial> 0637 0645
fd3b		<medial> 0638 0645
fd3c		<final> 0627 064B
fd3d		<isolated> 0627 064B
fd50		<initial> 062A 062C 0645
fd51		<final> 062A 062D 062C
fd52		<initial> 062A 062D 062C
fd53		<initial> 062A 062D 0645
fd54		<initial> 062A 062E 0645
fd55		<initial> 062A 0645 062C
fd56		<initial> 062A 0645 062D
fd57		<initial> 062A 0645 062E
fd58		<final> 062C 0645 062D
fd59		<initial> 062C 0645 062D
fd5a		<final> 062D 0645 064A
fd5b		<final> 062D 0645 0649
fd5c		<initial> 0633 062D 062C
fd5d		<initial> 0633 062C 062D
fd5e		<final> 0633 062C 0649
fd5f		<final> 0633 0645 062D
fd60		<initial> 0633 0645 062D
fd61		<initial> 0633 0645 062C
fd62		<final> 0633 0645 0645
fd63		<initial> 0633 0645 0645
fd64		<final> 0635 062D 062D
fd65		<initial> 0635 062D 062D
fd66		<final> 0635 0645 0645
fd67		<final> 0634 062D 0645
fd68		<initial> 0634 062D 0645
fd69		<final> 0634 062C 064A
fd6a		<final> 0634 0645 062E
fd6b		<initial> 0634 0645 062E
fd6c		<final> 0634 0645 0645
fd6d		<initial> 0634 0645 0645
fd6e		<final> 0636 062D 0649
fd6f		<final> 0636 062E 0645
fd70		<initial> 0636 062E 0645
fd71		<final> 0637 0645 062D
fd72		<initial> 0637 0645 062D
fd73		<initial> 0637 0645 0645
fd74		<final> 0637 0645 064A
fd75		<final> 0639 062C 0645
fd76		<final> 0639 0645 0645
fd77		<initial> 0639 0645 0645
fd78		<final> 0639 0645 0649
fd79		<final> 063A 0645 0645
fd7a		<final> 063A 0645 064A
fd7b		<final> 063A 0645 0649
fd7c		<final> 0641 062E 0645
fd7d		<initial> 0641 062E 0645
fd7e		<final> 0642 0645 062D
fd7f		<final> 0642 0645 0645
fd80		<final> 0644 062D 0645
fd81		<final> 0644 062D 064A
fd82		<final> 0644 062D 0649
fd83		<initial> 0644 062C 062C
fd84		<final> 0644 062C 062C
fd85		<final> 0644 062E 0645
fd86		<initial> 0644 062E 0645
fd87		<final> 0644 0645 062D
fd88		<initial> 0644 0645 062D
fd89		<initial> 0645 062D 062C
fd8a		<initial> 0645 062D 0645
fd8b		<final> 0645 062D 064A
fd8c		<initial> 0645 062C 062D
fd8d		<initial> 0645 062C 0645
fd8e		<initial> 0645 062E 062C
fd8f		<initial> 0645 062E 0645
fd92		<initial> 0645 062C 062E
fd93		<initial> 0647 0645 062C
fd94		<initial> 0647 0645 0645
fd95		<initial> 0646 062D 0645
fd96		<final> 0646 062D 0649
fd97		<final> 0646 062C 0645
fd98		<initial> 0646 062C 0645
fd99		<final> 0646 062C 0649
fd9a		<final> 0646 0645 064A
fd9b		<final> 0646 0645 0649
fd9c		<final> 064A 0645 0645
fd9d		<initial> 064A 0645 0645
fd9e		<final> 0628 062E 064A
fd9f		<final> 062A 062C 064A
fda0		<final> 062A 062C 0649
fda1		<final> 062A 062E 064A
fda2		<final> 062A 062E 0649
fda3		<final> 062A 0645 064A
fda4		<final> 062A 0645 0649
fda5		<final> 062C 0645 064A
fda6		<final> 062C 062D 0649
fda7		<final> 062C 0645 0649
fda8		<final> 0633 062E 0649
fda9		<final> 0635 062D 064A
fdaa		<final> 0634 062D 064A
fdab		<final> 0636 062D 064A
fdac		<final> 0644 062C 064A
fdad		<final> 0644 0645 064A
fdae		<final> 064A 062D 064A
fdaf		<final> 064A 062C 064A
fdb0		<final> 064A 0645 064A
fdb1		<final> 0645 0645 064A
fdb2		<final> 0642 0645 064A
fdb3		<final> 0646 062D 064A
fdb4		<initial> 0642 0645 062D
fdb5		<initial> 0644 062D 0645
fdb6		<final> 0639 0645 064A
fdb7		<final> 0643 0645 064A
fdb8		<initial> 0646 062C 062D
fdb9		<final> 0645 062E 064A
fdba		<initial> 0644 062C 0645
fdbb		<final> 0643 0645 0645
fdbc		<final> 0644 062C 0645
fdbd		<final> 0646 062C 062D
fdbe		<final> 062C 062D 064A
fdbf		<final> 062D 062C 064A
fdc0		<final> 0645 062C 064A
fdc1		<final> 0641 0645 064A
fdc2		<final> 0628 062D 064A
fdc3		<initial> 0643 0645 0645
fdc4		<initial> 0639 062C 0645
fdc5		<initial> 0635 0645 0645
fdc6		<final> 0633 062E 064A
fdc7		<final> 0646 062C 064A
fdf0		<isolated> 0635 0644 06D2
fdf1		<isolated> 0642 0644 06D2
fdf2		<isolated> 0627 0644 0644 0647
fdf3		<isolated> 0627 0643 0628 0631
fdf4		<isolated> 0645 062D 0645 062F
fdf5		<isolated> 0635 0644 0639 0645
fdf6		<isolated> 0631 0633 0648 0644
fdf7		<isolated> 0639 0644 064A 0647
fdf8		<isolated> 0648 0633 0644 0645
fdf9		<isolated> 0635 0644 0649
fdfa		<isolated> 0635 0644 0649 0020 0627 0644 0644 0647 0020 0639 0644 064A 0647 0020 0648 0633 0644 0645
fdfb		<isolated> 062C 0644 0020 062C 0644 0627 0644 0647
fe30		<vertical> 2025
fe31		<vertical> 2014
fe32		<vertical> 2013
fe33	fe34	<vertical> 005F
fe35		<vertical> 0028
fe36		<vertical> 0029
fe37		<vertical> 007B
fe38		<vertical> 007D
fe39		<vertical> 3014
fe3a		<vertical> 3015
fe3b		<vertical> 3010
fe3c		<vertical> 3011
fe3d		<vertical> 300A
fe3e		<vertical> 300B
fe3f		<vertical> 3008
fe40		<vertical> 3009
fe41		<vertical> 300C
fe42		<vertical> 300D
fe43		<vertical> 300E
fe44		<vertical> 300F
fe49	fe4c	<compat> 203E
fe4d	fe4f	<compat> 005F
fe50		<small> 002C
fe51		<small> 3001
fe52		<small> 002E
fe54		<small> 003B
fe55		<small> 003A
fe56		<small> 003F
fe57		<small> 0021
fe58		<small> 2014
fe59		<small> 0028
fe5a		<small> 0029
fe5b		<small> 007B
fe5c		<small> 007D
fe5d		<small> 3014
fe5e		<small> 3015
fe5f		<small> 0023
fe60		<small> 0026
fe61		<small> 002A
fe62		<small> 002B
fe63		<small> 002D
fe64		<small> 003C
fe65		<small> 003E
fe66		<small> 003D
fe68		<small> 005C
fe69		<small> 0024
fe6a		<small> 0025
fe6b		<small> 0040
fe70		<isolated> 0020 064B
fe71		<medial> 0640 064B
fe72		<isolated> 0020 064C
fe74		<isolated> 0020 064D
fe76		<isolated> 0020 064E
fe77		<medial> 0640 064E
fe78		<isolated> 0020 064F
fe79		<medial> 0640 064F
fe7a		<isolated> 0020 0650
fe7b		<medial> 0640 0650
fe7c		<isolated> 0020 0651
fe7d		<medial> 0640 0651
fe7e		<isolated> 0020 0652
fe7f		<medial> 0640 0652
fe80		<isolated> 0621
fe81		<isolated> 0622
fe82		<final> 0622
fe83		<isolated> 0623
fe84		<final> 0623
fe85		<isolated> 0624
fe86		<final> 0624
fe87		<isolated> 0625
fe88		<final> 0625
fe89		<isolated> 0626
fe8a		<final> 0626
fe8b		<initial> 0626
fe8c		<medial> 0626
fe8d		<isolated> 0627
fe8e		<final> 0627
fe8f		<isolated> 0628
fe90		<final> 0628
fe91		<initial> 0628
fe92		<medial> 0628
fe93		<isolated> 0629
fe94		<final> 0629
fe95		<isolated> 062A
fe96		<final> 062A
fe97		<initial> 062A
fe98		<medial> 062A
fe99		<isolated> 062B
fe9a		<final> 062B
fe9b		<initial> 062B
fe9c		<medial> 062B
fe9d		<isolated> 062C
fe9e		<final> 062C
fe9f		<initial> 062C
fea0		<medial> 062C
fea1		<isolated> 062D
fea2		<final> 062D
fea3		<initial> 062D
fea4		<medial> 062D
fea5		<isolated> 062E
fea6		<final> 062E
fea7		<initial> 062E
fea8		<medial> 062E
fea9		<isolated> 062F
feaa		<final> 062F
feab		<isolated> 0630
feac		<final> 0630
fead		<isolated> 0631
feae		<final> 0631
feaf		<isolated> 0632
feb0		<final> 0632
feb1		<isolated> 0633
feb2		<final> 0633
feb3		<initial> 0633
feb4		<medial> 0633
feb5		<isolated> 0634
feb6		<final> 0634
feb7		<initial> 0634
feb8		<medial> 0634
feb9		<isolated> 0635
feba		<final> 0635
febb		<initial> 0635
febc		<medial> 0635
febd		<isolated> 0636
febe		<final> 0636
febf		<initial> 0636
fec0		<medial> 0636
fec1		<isolated> 0637
fec2		<final> 0637
fec3		<initial> 0637
fec4		<medial> 0637
fec5		<isolated> 0638
fec6		<final> 0638
fec7		<initial> 0638
fec8		<medial> 0638
fec9		<isolated> 0639
feca		<final> 0639
fecb		<initial> 0639
fecc		<medial> 0639
fecd		<isolated> 063A
fece		<final> 063A
fecf		<initial> 063A
fed0		<medial> 063A
fed1		<isolated> 0641
fed2		<final> 0641
fed3		<initial> 0641
fed4		<medial> 0641
fed5		<isolated> 0642
fed6		<final> 0642
fed7		<initial> 0642
fed8		<medial> 0642
fed9		<isolated> 0643
feda		<final> 0643
fedb		<initial> 0643
fedc		<medial> 0643
fedd		<isolated> 0644
fede		<final> 0644
fedf		<initial> 0644
fee0		<medial> 0644
fee1		<isolated> 0645
fee2		<final> 0645
fee3		<initial> 0645
fee4		<medial> 0645
fee5		<isolated> 0646
fee6		<final> 0646
fee7		<initial> 0646
fee8		<medial> 0646
fee9		<isolated> 0647
feea		<final> 0647
feeb		<initial> 0647
feec		<medial> 0647
feed		<isolated> 0648
feee		<final> 0648
feef		<isolated> 0649
fef0		<final> 0649
fef1		<isolated> 064A
fef2		<final> 064A
fef3		<initial> 064A
fef4		<medial> 064A
fef5		<isolated> 0644 0622
fef6		<final> 0644 0622
fef7		<isolated> 0644 0623
fef8		<final> 0644 0623
fef9		<isolated> 0644 0625
fefa		<final> 0644 0625
fefb		<isolated> 0644 0627
fefc		<final> 0644 0627
ff01		<wide> 0021
ff02		<wide> 0022
ff03		<wide> 0023
ff04		<wide> 0024
ff05		<wide> 0025
ff06		<wide> 0026
ff07		<wide> 0027
ff08		<wide> 0028
ff09		<wide> 0029
ff0a		<wide> 002A
ff0b		<wide> 002B
ff0c		<wide> 002C
ff0d		<wide> 002D
ff0e		<wide> 002E
ff0f		<wide> 002F
ff10		<wide> 0030
ff11		<wide> 0031
ff12		<wide> 0032
ff13		<wide> 0033
ff14		<wide> 0034
ff15		<wide> 0035
ff16		<wide> 0036
ff17		<wide> 0037
ff18		<wide> 0038
ff19		<wide> 0039
ff1a		<wide> 003A
ff1b		<wide> 003B
ff1c		<wide> 003C
ff1d		<wide> 003D
ff1e		<wide> 003E
ff1f		<wide> 003F
ff20		<wide> 0040
ff21		<wide> 0041
ff22		<wide> 0042
ff23		<wide> 0043
ff24		<wide> 0044
ff25		<wide> 0045
ff26		<wide> 0046
ff27		<wide> 0047
ff28		<wide> 0048
ff29		<wide> 0049
ff2a		<wide> 004A
ff2b		<wide> 004B
ff2c		<wide> 004C
ff2d		<wide> 004D
ff2e		<wide> 004E
ff2f		<wide> 004F
ff30		<wide> 0050
ff31		<wide> 0051
ff32		<wide> 0052
ff33		<wide> 0053
ff34		<wide> 0054
ff35		<wide> 0055
ff36		<wide> 0056
ff37		<wide> 0057
ff38		<wide> 0058
ff39		<wide> 0059
ff3a		<wide> 005A
ff3b		<wide> 005B
ff3c		<wide> 005C
ff3d		<wide> 005D
ff3e		<wide> 005E
ff3f		<wide> 005F
ff40		<wide> 0060
ff41		<wide> 0061
ff42		<wide> 0062
ff43		<wide> 0063
ff44		<wide> 0064
ff45		<wide> 0065
ff46		<wide> 0066
ff47		<wide> 0067
ff48		<wide> 0068
ff49		<wide> 0069
ff4a		<wide> 006A
ff4b		<wide> 006B
ff4c		<wide> 006C
ff4d		<wide> 006D
ff4e		<wide> 006E
ff4f		<wide> 006F
ff50		<wide> 0070
ff51		<wide> 0071
ff52		<wide> 0072
ff53		<wide> 0073
ff54		<wide> 0074
ff55		<wide> 0075
ff56		<wide> 0076
ff57		<wide> 0077
ff58		<wide> 0078
ff59		<wide> 0079
ff5a		<wide> 007A
ff5b		<wide> 007B
ff5c		<wide> 007C
ff5d		<wide> 007D
ff5e		<wide> 007E
ff61		<narrow> 3002
ff62		<narrow> 300C
ff63		<narrow> 300D
ff64		<narrow> 3001
ff65		<narrow> 30FB
ff66		<narrow> 30F2
ff67		<narrow> 30A1
ff68		<narrow> 30A3
ff69		<narrow> 30A5
ff6a		<narrow> 30A7
ff6b		<narrow> 30A9
ff6c		<narrow> 30E3
ff6d		<narrow> 30E5
ff6e		<narrow> 30E7
ff6f		<narrow> 30C3
ff70		<narrow> 30FC
ff71		<narrow> 30A2
ff72		<narrow> 30A4
ff73		<narrow> 30A6
ff74		<narrow> 30A8
ff75		<narrow> 30AA
ff76		<narrow> 30AB
ff77		<narrow> 30AD
ff78		<narrow> 30AF
ff79		<narrow> 30B1
ff7a		<narrow> 30B3
ff7b		<narrow> 30B5
ff7c		<narrow> 30B7
ff7d		<narrow> 30B9
ff7e		<narrow> 30BB
ff7f		<narrow> 30BD
ff80		<narrow> 30BF
ff81		<narrow> 30C1
ff82		<narrow> 30C4
ff83		<narrow> 30C6
ff84		<narrow> 30C8
ff85		<narrow> 30CA
ff86		<narrow> 30CB
ff87		<narrow> 30CC
ff88		<narrow> 30CD
ff89		<narrow> 30CE
ff8a		<narrow> 30CF
ff8b		<narrow> 30D2
ff8c		<narrow> 30D5
ff8d		<narrow> 30D8
ff8e		<narrow> 30DB
ff8f		<narrow> 30DE
ff90		<narrow> 30DF
ff91		<narrow> 30E0
ff92		<narrow> 30E1
ff93		<narrow> 30E2
ff94		<narrow> 30E4
ff95		<narrow> 30E6
ff96		<narrow> 30E8
ff97		<narrow> 30E9
ff98		<narrow> 30EA
ff99		<narrow> 30EB
ff9a		<narrow> 30EC
ff9b		<narrow> 30ED
ff9c		<narrow> 30EF
ff9d		<narrow> 30F3
ff9e		<narrow> 3099
ff9f		<narrow> 309A
ffa0		<narrow> 3164
ffa1		<narrow> 3131
ffa2		<narrow> 3132
ffa3		<narrow> 3133
ffa4		<narrow> 3134
ffa5		<narrow> 3135
ffa6		<narrow> 3136
ffa7		<narrow> 3137
ffa8		<narrow> 3138
ffa9		<narrow> 3139
ffaa		<narrow> 313A
ffab		<narrow> 313B
ffac		<narrow> 313C
ffad		<narrow> 313D
ffae		<narrow> 313E
ffaf		<narrow> 313F
ffb0		<narrow> 3140
ffb1		<narrow> 3141
ffb2		<narrow> 3142
ffb3		<narrow> 3143
ffb4		<narrow> 3144
ffb5		<narrow> 3145
ffb6		<narrow> 3146
ffb7		<narrow> 3147
ffb8		<narrow> 3148
ffb9		<narrow> 3149
ffba		<narrow> 314A
ffbb		<narrow> 314B
ffbc		<narrow> 314C
ffbd		<narrow> 314D
ffbe		<narrow> 314E
ffc2		<narrow> 314F
ffc3		<narrow> 3150
ffc4		<narrow> 3151
ffc5		<narrow> 3152
ffc6		<narrow> 3153
ffc7		<narrow> 3154
ffca		<narrow> 3155
ffcb		<narrow> 3156
ffcc		<narrow> 3157
ffcd		<narrow> 3158
ffce		<narrow> 3159
ffcf		<narrow> 315A
ffd2		<narrow> 315B
ffd3		<narrow> 315C
ffd4		<narrow> 315D
ffd5		<narrow> 315E
ffd6		<narrow> 315F
ffd7		<narrow> 3160
ffda		<narrow> 3161
ffdb		<narrow> 3162
ffdc		<narrow> 3163
ffe0		<wide> 00A2
ffe1		<wide> 00A3
ffe2		<wide> 00AC
ffe3		<wide> 00AF
ffe4		<wide> 00A6
ffe5		<wide> 00A5
ffe6		<wide> 20A9
ffe8		<narrow> 2502
ffe9		<narrow> 2190
ffea		<narrow> 2191
ffeb		<narrow> 2192
ffec		<narrow> 2193
ffed		<narrow> 25A0
ffee		<narrow> 25CB
END
